#ifndef EFL_GENERATED_EVAS_3D_CAMERA_HH
#define EFL_GENERATED_EVAS_3D_CAMERA_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_3d_camera.eo.h"
}

#include "evas_3d_object.eo.hh"
#include "evas_common_interface.eo.hh"

struct evas_3d_camera;

namespace eo_cxx {

struct evas_3d_camera
{
   /// @brief Set the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to the array of 16 Evas_Real values in column major order.
   ///
   /// Default projection matrix is identity matrix.
   ///
   /// @see evas_3d_camera_projection_perspective_set()
   /// @see evas_3d_camera_projection_ortho_set()
   /// @see evas_3d_camera_projection_frustum_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param matrix Projection Matrix
   ///
   void projection_matrix_set(const Evas_Real * matrix_) const;


   /// @brief Get the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to receive the 16 Evas_Real values in column major order.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param[out] matrix Projection Matrix
   ///
   void projection_matrix_get(Evas_Real* matrix_) const;


   /// @brief Set the projection matrix of the given camera with perspective projection.
   ///
   /// @param camera     The given camera.
   /// @param fovy       Field of view angle in Y direction.
   /// @param aspect     Aspect ratio.
   /// @param dnear      Distance to near clipping plane.
   /// @param dfar       Distance to far clipping plane.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param fovy Field of view angle in Y direction.
   /// @param aspect Aspect ratio.
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Set the projection matrix of the given camera with frustum projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Set the projection matrix of the given camera with orthogonal projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Check is bounding sphere of given node inside frustum of camera node.
   /// *
   /// * @param camera          The given camera node.
   /// * @param node            The given node.
   /// * @return                @c EINA_TRUE in frustum, @c EINA_FALSE otherwise
   ///
   /// * If the nodes are @ NULL or nodes type mismatch error wrong type of nodes will be generated and returned @ EINA_FALSE.
   ///
   /// * @ingroup Evas_3D_Camera
   ///
   /// @param camera_node 
   /// @param node 
   /// @param key 
   ///
   bool node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_CAMERA_CLASS);
   }

   operator ::evas_3d_camera() const;
   operator ::evas_3d_camera&();
   operator ::evas_3d_camera const&() const;

   template <typename D>
   struct address_of
   {
      operator ::evas_3d_camera*() const { return static_cast<::evas_3d_camera*>(static_cast<D const*>(this)->p); }
      operator ::evas_3d_camera const*() const { return static_cast<::evas_3d_camera const*>(static_cast<D const*>(this)->p); }
   };

   template <typename D>
   struct address_const_of
   {
      operator ::evas_3d_camera const*() const { return static_cast<::evas_3d_camera const*>(static_cast<D const*>(this)->p); }
   };

private:
   Eo* _concrete_eo_ptr() const
   {
      return static_cast<::efl::eo::concrete const*>(static_cast<void const*>(this))->_eo_ptr();
   }

};

}

struct evas_3d_camera
      : ::efl::eo::concrete
      , ::eo_cxx::eo::base
      , ::eo_cxx::evas::common_interface
      , ::eo_cxx::evas_3d_object
{
   evas_3d_camera(::efl::eo::parent_type _p = (::efl::eo::parent = nullptr))
      : evas_3d_camera(_ctors_call(_p))
   {}

   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_3d_camera(Eo* eo)
      : ::efl::eo::concrete(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit evas_3d_camera(std::nullptr_t)
      : ::efl::eo::concrete(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   evas_3d_camera(evas_3d_camera const& other)
      : evas_3d_camera(eo_ref(other._eo_ptr()))
   {}

   ~evas_3d_camera() {}

   /// @brief Set the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to the array of 16 Evas_Real values in column major order.
   ///
   /// Default projection matrix is identity matrix.
   ///
   /// @see evas_3d_camera_projection_perspective_set()
   /// @see evas_3d_camera_projection_ortho_set()
   /// @see evas_3d_camera_projection_frustum_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param matrix Projection Matrix
   ///
   void projection_matrix_set(const Evas_Real * matrix_) const;


   /// @brief Get the projection matrix of the given camera.
   ///
   /// @param camera     The given camera.
   /// @param matrix     Pointer to receive the 16 Evas_Real values in column major order.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param[out] matrix Projection Matrix
   ///
   void projection_matrix_get(Evas_Real* matrix_) const;


   /// @brief Set the projection matrix of the given camera with perspective projection.
   ///
   /// @param camera     The given camera.
   /// @param fovy       Field of view angle in Y direction.
   /// @param aspect     Aspect ratio.
   /// @param dnear      Distance to near clipping plane.
   /// @param dfar       Distance to far clipping plane.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param fovy Field of view angle in Y direction.
   /// @param aspect Aspect ratio.
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Set the projection matrix of the given camera with frustum projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Set the projection matrix of the given camera with orthogonal projection.
   ///
   /// @see evas_3d_camera_projection_matrix_set()
   ///
   /// @ingroup Evas_3D_Camera
   ///
   /// @param left Left X coordinate of the near clipping plane.
   /// @param right Right X coordinate of the near clipping plane..
   /// @param bottom Bottom Y coordinate of the near clipping plane.
   /// @param top Top Y coordinate of the near clipping plane
   /// @param dnear Distance to near clipping plane.
   /// @param dfar Distance to far clipping plane.
   ///
   void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const;


   /// @brief Check is bounding sphere of given node inside frustum of camera node.
   /// *
   /// * @param camera          The given camera node.
   /// * @param node            The given node.
   /// * @return                @c EINA_TRUE in frustum, @c EINA_FALSE otherwise
   ///
   /// * If the nodes are @ NULL or nodes type mismatch error wrong type of nodes will be generated and returned @ EINA_FALSE.
   ///
   /// * @ingroup Evas_3D_Camera
   ///
   /// @param camera_node 
   /// @param node 
   /// @param key 
   ///
   bool node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_CAMERA_CLASS);
   }

   struct address_of
      : ::eo_cxx::evas_3d_camera::address_of<address_of>
      , ::eo_cxx::eo::base::address_of<address_of>
      , ::eo_cxx::evas::common_interface::address_of<address_of>
      , ::eo_cxx::evas_3d_object::address_of<address_of>
      , ::efl::eo::detail::concrete_address_of
   {
      explicit address_of(::evas_3d_camera* p)
         : ::efl::eo::detail::concrete_address_of(p)
      {}
   };
   address_of operator&() { return address_of(this); }

   struct address_const_of
      : ::eo_cxx::evas_3d_camera::address_const_of<address_const_of>
      , ::eo_cxx::eo::base::address_const_of<address_const_of>
      , ::eo_cxx::evas::common_interface::address_const_of<address_const_of>
      , ::eo_cxx::evas_3d_object::address_const_of<address_const_of>
      , ::efl::eo::detail::concrete_address_const_of
   {
      explicit address_const_of(::evas_3d_camera const* p)
         : ::efl::eo::detail::concrete_address_const_of(p)
      {}
   };
   address_const_of operator&() const { return address_const_of(this); }

private:
   static Eo* _ctors_call(::efl::eo::parent_type _p)
   {
      Eo* _ret_eo = eo_add_ref(EVAS_3D_CAMERA_CLASS, _p._eo_raw, );

      return _ret_eo;
   }

      Eo* _concrete_eo_ptr() const { return _eo_ptr(); }
};

static_assert(sizeof(::evas_3d_camera) == sizeof(Eo*), "");
static_assert(std::is_standard_layout<::evas_3d_camera>::value, "");

inline void evas_3d_camera::projection_matrix_set(const Evas_Real * matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
}


inline void evas_3d_camera::projection_matrix_get(Evas_Real* matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
}


inline void evas_3d_camera::projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
}


inline void evas_3d_camera::projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
}


inline void evas_3d_camera::projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
}


inline bool evas_3d_camera::node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas_3d_camera::projection_matrix_set(const Evas_Real * matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_set(matrix_));
}


inline void eo_cxx::evas_3d_camera::projection_matrix_get(Evas_Real* matrix_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_matrix_get(matrix_));
}


inline void eo_cxx::evas_3d_camera::projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
}


inline void eo_cxx::evas_3d_camera::projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
}


inline void eo_cxx::evas_3d_camera::projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
}


inline bool eo_cxx::evas_3d_camera::node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera() const
{
   return *static_cast<::evas_3d_camera const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera&()
{
   return *static_cast<::evas_3d_camera*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas_3d_camera::operator ::evas_3d_camera const&() const
{
   return *static_cast<::evas_3d_camera const*>(static_cast<void const*>(this));
}

template <typename T>
void _evas_3d_camera_projection_matrix_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const Evas_Real * matrix_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_matrix_set(matrix_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_matrix_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real* matrix_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_matrix_get(matrix_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_perspective_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_perspective_set(fovy_, aspect_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_frustum_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_camera_projection_ortho_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
{
   try
      {
         static_cast<T*>(self->this_)->projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool _evas_3d_camera_node_visible_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->node_visible_get(camera_node_, node_, key_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_camera >
{
   template <typename T>
   struct type
         : virtual operations< ::evas_3d_object >::template type<T>
         , virtual operations< ::evas::common_interface >::template type<T>
   {
      virtual void projection_matrix_set(const Evas_Real * matrix_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_set(matrix_));
      }

      virtual void projection_matrix_get(Evas_Real* matrix_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_matrix_get(matrix_));
      }

      virtual void projection_perspective_set(Evas_Real fovy_, Evas_Real aspect_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_perspective_set(fovy_, aspect_, dnear_, dfar_));
      }

      virtual void projection_frustum_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_frustum_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual void projection_ortho_set(Evas_Real left_, Evas_Real right_, Evas_Real bottom_, Evas_Real top_, Evas_Real dnear_, Evas_Real dfar_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_camera_projection_ortho_set(left_, right_, bottom_, top_, dnear_, dfar_));
      }

      virtual bool node_visible_get(Evas_3D_Node * camera_node_, Evas_3D_Node * node_, Evas_3D_Frustum_Mode key_)
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_camera_node_visible_get(camera_node_, node_, key_));
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

   };
};


template<>
struct operation_description_class_size< ::evas_3d_camera >
{
   static const int value = 6 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value;
};

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas_3d_camera>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_matrix_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_matrix_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_perspective_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_perspective_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_frustum_set_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_frustum_set);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_camera_projection_ortho_set_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_projection_ortho_set);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_camera_node_visible_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_camera_node_visible_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas_3d_object>(), &ops[6]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::common_interface>(), &ops[6 + operation_description_class_size<::evas_3d_object>::value]);
   return 0;
}
inline void
call_constructor(::efl::eo::detail::tag< ::evas_3d_camera >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               ::efl::eo::detail::args_class<::evas_3d_camera, ::std::tuple<::efl::eo::parent_type> > const& args)
{
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

inline Eo_Class const* get_eo_class(tag<::evas_3d_camera>)
{
   return (EVAS_3D_CAMERA_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_3D_CAMERA_HH

