#ifndef EFL_GENERATED_EVAS_3D_MESH_HH
#define EFL_GENERATED_EVAS_3D_MESH_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_3d_mesh.eo.h"
}

#include "evas_3d_object.eo.hh"
#include "evas_common_interface.eo.hh"
#include "efl_file.eo.hh"
#include <string>

struct evas_3d_mesh;

namespace eo_cxx {

struct evas_3d_mesh
{
   /// @param file Eina_File with mesh data.
   /// @param key Key in the mesh file.
   ///
   void mmap_set(Eina_File * file_, ::efl::eina::optional< std::string > key_) const;


   /// @brief Set the vertex data of the key frame of the given mesh.
   ///
   /// This function make evas read from the given buffer whenever it requires.
   /// If you want to release the buffer after calling this functions, use
   /// evas_3d_mesh_frame_vertex_data_copy_set() instead.
   ///
   /// After setting the vertex data, further modifications should be protected
   /// by map/unmap pair.
   ///
   /// @see evas_3d_mesh_frame_vertex_data_copy_set()
   /// @see evas_3d_mesh_frame_vertex_data_map()
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   /// @param stride Stride to go to the next vertex (in bytes).
   /// @param data Pointer to the vertex data buffer.
   ///
   void frame_vertex_data_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const;


   /// @brief Set the vertex data of the key frame of the given mesh by copying from a buffer.
   /// This function allocates internal vertex buffer and copy from the given
   /// buffer. So you can release the buffer. If you want to modify the vertex data
   /// use evas_3d_mesh_frame_vertex_data_map(). After finishing the modifications,
   /// you should call evas_3d_mesh_frame_vertex_data_unmap().
   ///
   /// @see evas_3d_mesh_frame_vertex_data_set()
   /// @see evas_3d_mesh_frame_vertex_data_map()
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   /// @param stride Stride to go to the next vertex (in bytes).
   /// @param data Pointer to the vertex data buffer.
   ///
   void frame_vertex_data_copy_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const;


   /// @brief Map the vertex buffer of the key frame of the given mesh.
   ///
   /// After manipulating the mapped buffer, evas_3d_mesh_frame_vertex_data_unmap()
   /// should be called to properly download the data to the engine. If the data
   /// was set using evas_3d_mesh_frame_vertex_data_set(), pointer to the original
   /// buffer will be returned. Otherwise, the returned pointer can differ every
   /// time calling this function.
   ///
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   /// @return Starting address of the mapped vertex buffer.
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   void * frame_vertex_data_map(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   void frame_vertex_data_unmap(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   int frame_vertex_stride_get(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param format Vertex index data format.
   /// @param count Vertex index count.
   /// @param indices Pointer to the index data.
   ///
   void index_data_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const;


   /// @param format Vertex index data format.
   /// @param count Vertex index count.
   /// @param indices Pointer to the index data.
   ///
   void index_data_copy_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const;


   Evas_3D_Index_Format index_format_get() const;


   int index_count_get() const;


   void * index_data_map() const;


   void index_data_unmap() const;


   /// @param frame The number of the key frame to be added.
   ///
   void frame_add(int frame_) const;


   /// @param frame The number of the key frame to be added.
   ///
   void frame_del(int frame_) const;


   /// @brief Set the vertex count of the given mesh.
   ///
   /// Each key frame should have same vertex count to be properly interpolated.
   /// Key frames have their own vertex data and the data should have more vertices
   /// than the mesh's vertex count.
   ///
   /// Default vertex count is 0.
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param count Vertex count.
   ///
   void vertex_count_set(unsigned int count_) const;


   /// @brief Get the vertex count of the given mesh.
   ///
   /// @see evas_3d_mesh_vertex_count_set()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   int vertex_count_get() const;


   /// @param r The red component of the fog color.
   /// @param g The green component of the fog color.
   /// @param b The blue component of the fog color.
   /// @param a The transparency of fog.
   ///
   void fog_color_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const;


   /// @param[out] r Pointer to receive red component of the fog color.
   /// @param[out] g Pointer to receive green component of the fog color.
   /// @param[out] b Pointer to receive blue component of the fog color.
   /// @param[out] a Pointer to receive transparency of fog.
   ///
   void fog_color_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const;


   /// @param sfactor Specifies how the red, green, blue, and alpha source blending factors are computed.
   /// @param dfactor Specifies how the red, green, blue, and alpha destination blending factors are computed.
   ///
   void blending_func_set(Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_) const;


   /// @param[out] sfactor Pointer to receive source blendin factors key.
   /// @param[out] dfactor Pointer to receive destination blendin factors key.
   ///
   void blending_func_get(Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_) const;


   /// @param enabled The red component of the fog color.
   ///
   void fog_enable_set(bool enabled_) const;


   bool fog_enable_get() const;


   /// @param mode The shade mode.
   ///
   Evas_3D_Shade_Mode shade_mode_get() const;


   /// @param mode The shade mode.
   ///
   void shade_mode_set(Evas_3D_Shade_Mode mode_) const;


   /// @param blending The blending state.
   ///
   bool blending_enable_get() const;


   /// @param blending The blending state.
   ///
   void blending_enable_set(bool blending_) const;


   /// @param material The material to be set to the key frame.
   ///
   Evas_3D_Material * frame_material_get(int frame_) const;


   /// @param material The material to be set to the key frame.
   ///
   void frame_material_set(int frame_, Evas_3D_Material * material_) const;


   /// @param assembly Vertex assembly.
   ///
   Evas_3D_Vertex_Assembly vertex_assembly_get() const;


   /// @param assembly Vertex assembly.
   ///
   void vertex_assembly_set(Evas_3D_Vertex_Assembly assembly_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_MESH_CLASS);
   }

   operator ::evas_3d_mesh() const;
   operator ::evas_3d_mesh&();
   operator ::evas_3d_mesh const&() const;

   template <typename D>
   struct address_of
   {
      operator ::evas_3d_mesh*() const { return static_cast<::evas_3d_mesh*>(static_cast<D const*>(this)->p); }
      operator ::evas_3d_mesh const*() const { return static_cast<::evas_3d_mesh const*>(static_cast<D const*>(this)->p); }
   };

   template <typename D>
   struct address_const_of
   {
      operator ::evas_3d_mesh const*() const { return static_cast<::evas_3d_mesh const*>(static_cast<D const*>(this)->p); }
   };

private:
   Eo* _concrete_eo_ptr() const
   {
      return static_cast<::efl::eo::concrete const*>(static_cast<void const*>(this))->_eo_ptr();
   }

};

}

struct evas_3d_mesh
      : ::efl::eo::concrete
      , ::eo_cxx::efl::file
      , ::eo_cxx::eo::base
      , ::eo_cxx::evas::common_interface
      , ::eo_cxx::evas_3d_object
{
   evas_3d_mesh(::efl::eo::parent_type _p = (::efl::eo::parent = nullptr))
      : evas_3d_mesh(_ctors_call(_p))
   {}

   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit evas_3d_mesh(Eo* eo)
      : ::efl::eo::concrete(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit evas_3d_mesh(std::nullptr_t)
      : ::efl::eo::concrete(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   evas_3d_mesh(evas_3d_mesh const& other)
      : evas_3d_mesh(eo_ref(other._eo_ptr()))
   {}

   ~evas_3d_mesh() {}

   /// @param file Eina_File with mesh data.
   /// @param key Key in the mesh file.
   ///
   void mmap_set(Eina_File * file_, ::efl::eina::optional< std::string > key_) const;


   /// @brief Set the vertex data of the key frame of the given mesh.
   ///
   /// This function make evas read from the given buffer whenever it requires.
   /// If you want to release the buffer after calling this functions, use
   /// evas_3d_mesh_frame_vertex_data_copy_set() instead.
   ///
   /// After setting the vertex data, further modifications should be protected
   /// by map/unmap pair.
   ///
   /// @see evas_3d_mesh_frame_vertex_data_copy_set()
   /// @see evas_3d_mesh_frame_vertex_data_map()
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   /// @param stride Stride to go to the next vertex (in bytes).
   /// @param data Pointer to the vertex data buffer.
   ///
   void frame_vertex_data_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const;


   /// @brief Set the vertex data of the key frame of the given mesh by copying from a buffer.
   /// This function allocates internal vertex buffer and copy from the given
   /// buffer. So you can release the buffer. If you want to modify the vertex data
   /// use evas_3d_mesh_frame_vertex_data_map(). After finishing the modifications,
   /// you should call evas_3d_mesh_frame_vertex_data_unmap().
   ///
   /// @see evas_3d_mesh_frame_vertex_data_set()
   /// @see evas_3d_mesh_frame_vertex_data_map()
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   /// @param stride Stride to go to the next vertex (in bytes).
   /// @param data Pointer to the vertex data buffer.
   ///
   void frame_vertex_data_copy_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const;


   /// @brief Map the vertex buffer of the key frame of the given mesh.
   ///
   /// After manipulating the mapped buffer, evas_3d_mesh_frame_vertex_data_unmap()
   /// should be called to properly download the data to the engine. If the data
   /// was set using evas_3d_mesh_frame_vertex_data_set(), pointer to the original
   /// buffer will be returned. Otherwise, the returned pointer can differ every
   /// time calling this function.
   ///
   /// @see evas_3d_mesh_frame_vertex_data_unmap()
   /// @return Starting address of the mapped vertex buffer.
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   void * frame_vertex_data_map(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   void frame_vertex_data_unmap(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param frame The number of the key frame.
   /// @param attrib Vertex attribute ID.
   ///
   int frame_vertex_stride_get(int frame_, Evas_3D_Vertex_Attrib attrib_) const;


   /// @param format Vertex index data format.
   /// @param count Vertex index count.
   /// @param indices Pointer to the index data.
   ///
   void index_data_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const;


   /// @param format Vertex index data format.
   /// @param count Vertex index count.
   /// @param indices Pointer to the index data.
   ///
   void index_data_copy_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const;


   Evas_3D_Index_Format index_format_get() const;


   int index_count_get() const;


   void * index_data_map() const;


   void index_data_unmap() const;


   /// @param frame The number of the key frame to be added.
   ///
   void frame_add(int frame_) const;


   /// @param frame The number of the key frame to be added.
   ///
   void frame_del(int frame_) const;


   /// @brief Set the vertex count of the given mesh.
   ///
   /// Each key frame should have same vertex count to be properly interpolated.
   /// Key frames have their own vertex data and the data should have more vertices
   /// than the mesh's vertex count.
   ///
   /// Default vertex count is 0.
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   /// @param count Vertex count.
   ///
   void vertex_count_set(unsigned int count_) const;


   /// @brief Get the vertex count of the given mesh.
   ///
   /// @see evas_3d_mesh_vertex_count_set()
   ///
   /// @ingroup Evas_3D_Mesh
   ///
   int vertex_count_get() const;


   /// @param r The red component of the fog color.
   /// @param g The green component of the fog color.
   /// @param b The blue component of the fog color.
   /// @param a The transparency of fog.
   ///
   void fog_color_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const;


   /// @param[out] r Pointer to receive red component of the fog color.
   /// @param[out] g Pointer to receive green component of the fog color.
   /// @param[out] b Pointer to receive blue component of the fog color.
   /// @param[out] a Pointer to receive transparency of fog.
   ///
   void fog_color_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const;


   /// @param sfactor Specifies how the red, green, blue, and alpha source blending factors are computed.
   /// @param dfactor Specifies how the red, green, blue, and alpha destination blending factors are computed.
   ///
   void blending_func_set(Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_) const;


   /// @param[out] sfactor Pointer to receive source blendin factors key.
   /// @param[out] dfactor Pointer to receive destination blendin factors key.
   ///
   void blending_func_get(Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_) const;


   /// @param enabled The red component of the fog color.
   ///
   void fog_enable_set(bool enabled_) const;


   bool fog_enable_get() const;


   /// @param mode The shade mode.
   ///
   Evas_3D_Shade_Mode shade_mode_get() const;


   /// @param mode The shade mode.
   ///
   void shade_mode_set(Evas_3D_Shade_Mode mode_) const;


   /// @param blending The blending state.
   ///
   bool blending_enable_get() const;


   /// @param blending The blending state.
   ///
   void blending_enable_set(bool blending_) const;


   /// @param material The material to be set to the key frame.
   ///
   Evas_3D_Material * frame_material_get(int frame_) const;


   /// @param material The material to be set to the key frame.
   ///
   void frame_material_set(int frame_, Evas_3D_Material * material_) const;


   /// @param assembly Vertex assembly.
   ///
   Evas_3D_Vertex_Assembly vertex_assembly_get() const;


   /// @param assembly Vertex assembly.
   ///
   void vertex_assembly_set(Evas_3D_Vertex_Assembly assembly_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_3D_MESH_CLASS);
   }

   struct address_of
      : ::eo_cxx::evas_3d_mesh::address_of<address_of>
      , ::eo_cxx::efl::file::address_of<address_of>
      , ::eo_cxx::eo::base::address_of<address_of>
      , ::eo_cxx::evas::common_interface::address_of<address_of>
      , ::eo_cxx::evas_3d_object::address_of<address_of>
      , ::efl::eo::detail::concrete_address_of
   {
      explicit address_of(::evas_3d_mesh* p)
         : ::efl::eo::detail::concrete_address_of(p)
      {}
   };
   address_of operator&() { return address_of(this); }

   struct address_const_of
      : ::eo_cxx::evas_3d_mesh::address_const_of<address_const_of>
      , ::eo_cxx::efl::file::address_const_of<address_const_of>
      , ::eo_cxx::eo::base::address_const_of<address_const_of>
      , ::eo_cxx::evas::common_interface::address_const_of<address_const_of>
      , ::eo_cxx::evas_3d_object::address_const_of<address_const_of>
      , ::efl::eo::detail::concrete_address_const_of
   {
      explicit address_const_of(::evas_3d_mesh const* p)
         : ::efl::eo::detail::concrete_address_const_of(p)
      {}
   };
   address_const_of operator&() const { return address_const_of(this); }

private:
   static Eo* _ctors_call(::efl::eo::parent_type _p)
   {
      Eo* _ret_eo = eo_add_ref(EVAS_3D_MESH_CLASS, _p._eo_raw, );

      return _ret_eo;
   }

      Eo* _concrete_eo_ptr() const { return _eo_ptr(); }
};

static_assert(sizeof(::evas_3d_mesh) == sizeof(Eo*), "");
static_assert(std::is_standard_layout<::evas_3d_mesh>::value, "");

inline void evas_3d_mesh::mmap_set(Eina_File * file_, ::efl::eina::optional< std::string > key_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_mmap_set(file_, ::efl::eolian::to_c(key_)));
}


inline void evas_3d_mesh::frame_vertex_data_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_set(frame_, attrib_, stride_, data_));
}


inline void evas_3d_mesh::frame_vertex_data_copy_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_copy_set(frame_, attrib_, stride_, data_));
}


inline void * evas_3d_mesh::frame_vertex_data_map(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   void * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_vertex_data_map(frame_, attrib_));
   return _tmp_ret;
}


inline void evas_3d_mesh::frame_vertex_data_unmap(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_unmap(frame_, attrib_));
}


inline int evas_3d_mesh::frame_vertex_stride_get(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_vertex_stride_get(frame_, attrib_));
   return _tmp_ret;
}


inline void evas_3d_mesh::index_data_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_set(format_, count_, indices_));
}


inline void evas_3d_mesh::index_data_copy_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_copy_set(format_, count_, indices_));
}


inline Evas_3D_Index_Format evas_3d_mesh::index_format_get() const
{
   Evas_3D_Index_Format _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_format_get());
   return _tmp_ret;
}


inline int evas_3d_mesh::index_count_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_count_get());
   return _tmp_ret;
}


inline void * evas_3d_mesh::index_data_map() const
{
   void * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_data_map());
   return _tmp_ret;
}


inline void evas_3d_mesh::index_data_unmap() const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_unmap());
}


inline void evas_3d_mesh::frame_add(int frame_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_add(frame_));
}


inline void evas_3d_mesh::frame_del(int frame_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_del(frame_));
}


inline void evas_3d_mesh::vertex_count_set(unsigned int count_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_vertex_count_set(count_));
}


inline int evas_3d_mesh::vertex_count_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_vertex_count_get());
   return _tmp_ret;
}


inline void evas_3d_mesh::fog_color_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_color_set(r_, g_, b_, a_));
}


inline void evas_3d_mesh::fog_color_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_color_get(r_, g_, b_, a_));
}


inline void evas_3d_mesh::blending_func_set(Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_func_set(sfactor_, dfactor_));
}


inline void evas_3d_mesh::blending_func_get(Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_func_get(sfactor_, dfactor_));
}


inline void evas_3d_mesh::fog_enable_set(bool enabled_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_enable_set(::efl::eolian::to_c(enabled_)));
}


inline bool evas_3d_mesh::fog_enable_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_fog_enable_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline Evas_3D_Shade_Mode evas_3d_mesh::shade_mode_get() const
{
   Evas_3D_Shade_Mode _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_shade_mode_get());
   return _tmp_ret;
}


inline void evas_3d_mesh::shade_mode_set(Evas_3D_Shade_Mode mode_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_shade_mode_set(mode_));
}


inline bool evas_3d_mesh::blending_enable_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_blending_enable_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas_3d_mesh::blending_enable_set(bool blending_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_enable_set(::efl::eolian::to_c(blending_)));
}


inline Evas_3D_Material * evas_3d_mesh::frame_material_get(int frame_) const
{
   Evas_3D_Material * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_material_get(frame_));
   return _tmp_ret;
}


inline void evas_3d_mesh::frame_material_set(int frame_, Evas_3D_Material * material_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_material_set(frame_, material_));
}


inline Evas_3D_Vertex_Assembly evas_3d_mesh::vertex_assembly_get() const
{
   Evas_3D_Vertex_Assembly _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_vertex_assembly_get());
   return _tmp_ret;
}


inline void evas_3d_mesh::vertex_assembly_set(Evas_3D_Vertex_Assembly assembly_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_vertex_assembly_set(assembly_));
}


inline void eo_cxx::evas_3d_mesh::mmap_set(Eina_File * file_, ::efl::eina::optional< std::string > key_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_mmap_set(file_, ::efl::eolian::to_c(key_)));
}


inline void eo_cxx::evas_3d_mesh::frame_vertex_data_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_set(frame_, attrib_, stride_, data_));
}


inline void eo_cxx::evas_3d_mesh::frame_vertex_data_copy_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_copy_set(frame_, attrib_, stride_, data_));
}


inline void * eo_cxx::evas_3d_mesh::frame_vertex_data_map(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   void * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_vertex_data_map(frame_, attrib_));
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::frame_vertex_data_unmap(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_vertex_data_unmap(frame_, attrib_));
}


inline int eo_cxx::evas_3d_mesh::frame_vertex_stride_get(int frame_, Evas_3D_Vertex_Attrib attrib_) const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_vertex_stride_get(frame_, attrib_));
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::index_data_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_set(format_, count_, indices_));
}


inline void eo_cxx::evas_3d_mesh::index_data_copy_set(Evas_3D_Index_Format format_, int count_, const void * indices_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_copy_set(format_, count_, indices_));
}


inline Evas_3D_Index_Format eo_cxx::evas_3d_mesh::index_format_get() const
{
   Evas_3D_Index_Format _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_format_get());
   return _tmp_ret;
}


inline int eo_cxx::evas_3d_mesh::index_count_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_count_get());
   return _tmp_ret;
}


inline void * eo_cxx::evas_3d_mesh::index_data_map() const
{
   void * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_index_data_map());
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::index_data_unmap() const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_index_data_unmap());
}


inline void eo_cxx::evas_3d_mesh::frame_add(int frame_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_add(frame_));
}


inline void eo_cxx::evas_3d_mesh::frame_del(int frame_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_del(frame_));
}


inline void eo_cxx::evas_3d_mesh::vertex_count_set(unsigned int count_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_vertex_count_set(count_));
}


inline int eo_cxx::evas_3d_mesh::vertex_count_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_vertex_count_get());
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::fog_color_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_color_set(r_, g_, b_, a_));
}


inline void eo_cxx::evas_3d_mesh::fog_color_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_color_get(r_, g_, b_, a_));
}


inline void eo_cxx::evas_3d_mesh::blending_func_set(Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_func_set(sfactor_, dfactor_));
}


inline void eo_cxx::evas_3d_mesh::blending_func_get(Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_func_get(sfactor_, dfactor_));
}


inline void eo_cxx::evas_3d_mesh::fog_enable_set(bool enabled_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_fog_enable_set(::efl::eolian::to_c(enabled_)));
}


inline bool eo_cxx::evas_3d_mesh::fog_enable_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_fog_enable_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline Evas_3D_Shade_Mode eo_cxx::evas_3d_mesh::shade_mode_get() const
{
   Evas_3D_Shade_Mode _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_shade_mode_get());
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::shade_mode_set(Evas_3D_Shade_Mode mode_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_shade_mode_set(mode_));
}


inline bool eo_cxx::evas_3d_mesh::blending_enable_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_blending_enable_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas_3d_mesh::blending_enable_set(bool blending_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_blending_enable_set(::efl::eolian::to_c(blending_)));
}


inline Evas_3D_Material * eo_cxx::evas_3d_mesh::frame_material_get(int frame_) const
{
   Evas_3D_Material * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_frame_material_get(frame_));
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::frame_material_set(int frame_, Evas_3D_Material * material_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_frame_material_set(frame_, material_));
}


inline Evas_3D_Vertex_Assembly eo_cxx::evas_3d_mesh::vertex_assembly_get() const
{
   Evas_3D_Vertex_Assembly _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_3d_mesh_vertex_assembly_get());
   return _tmp_ret;
}


inline void eo_cxx::evas_3d_mesh::vertex_assembly_set(Evas_3D_Vertex_Assembly assembly_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_3d_mesh_vertex_assembly_set(assembly_));
}


inline ::eo_cxx::evas_3d_mesh::operator ::evas_3d_mesh() const
{
   return *static_cast<::evas_3d_mesh const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas_3d_mesh::operator ::evas_3d_mesh&()
{
   return *static_cast<::evas_3d_mesh*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas_3d_mesh::operator ::evas_3d_mesh const&() const
{
   return *static_cast<::evas_3d_mesh const*>(static_cast<void const*>(this));
}

template <typename T>
void _evas_3d_mesh_mmap_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_File * file_, const char * key_)
{
   try
      {
         static_cast<T*>(self->this_)->mmap_set(file_, ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(key_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_frame_vertex_data_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_vertex_data_set(frame_, attrib_, stride_, data_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_frame_vertex_data_copy_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_vertex_data_copy_set(frame_, attrib_, stride_, data_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void * _evas_3d_mesh_frame_vertex_data_map_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Vertex_Attrib attrib_)
{
   void * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->frame_vertex_data_map(frame_, attrib_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_frame_vertex_data_unmap_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Vertex_Attrib attrib_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_vertex_data_unmap(frame_, attrib_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
int _evas_3d_mesh_frame_vertex_stride_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Vertex_Attrib attrib_)
{
   int _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->frame_vertex_stride_get(frame_, attrib_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_index_data_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Index_Format format_, int count_, const void * indices_)
{
   try
      {
         static_cast<T*>(self->this_)->index_data_set(format_, count_, indices_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_index_data_copy_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Index_Format format_, int count_, const void * indices_)
{
   try
      {
         static_cast<T*>(self->this_)->index_data_copy_set(format_, count_, indices_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_3D_Index_Format _evas_3d_mesh_index_format_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_3D_Index_Format _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->index_format_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
int _evas_3d_mesh_index_count_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   int _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->index_count_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void * _evas_3d_mesh_index_data_map_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   void * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->index_data_map();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_index_data_unmap_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->index_data_unmap();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_frame_add_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_add(frame_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_frame_del_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_del(frame_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_vertex_count_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, unsigned int count_)
{
   try
      {
         static_cast<T*>(self->this_)->vertex_count_set(count_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
int _evas_3d_mesh_vertex_count_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   int _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->vertex_count_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_fog_color_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
{
   try
      {
         static_cast<T*>(self->this_)->fog_color_set(r_, g_, b_, a_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_fog_color_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
{
   try
      {
         static_cast<T*>(self->this_)->fog_color_get(r_, g_, b_, a_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_blending_func_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_)
{
   try
      {
         static_cast<T*>(self->this_)->blending_func_set(sfactor_, dfactor_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_blending_func_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_)
{
   try
      {
         static_cast<T*>(self->this_)->blending_func_get(sfactor_, dfactor_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void _evas_3d_mesh_fog_enable_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_Bool enabled_)
{
   try
      {
         static_cast<T*>(self->this_)->fog_enable_set(::efl::eolian::to_cxx<bool>(enabled_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool _evas_3d_mesh_fog_enable_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->fog_enable_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
Evas_3D_Shade_Mode _evas_3d_mesh_shade_mode_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_3D_Shade_Mode _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->shade_mode_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_shade_mode_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Shade_Mode mode_)
{
   try
      {
         static_cast<T*>(self->this_)->shade_mode_set(mode_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool _evas_3d_mesh_blending_enable_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->blending_enable_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_blending_enable_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_Bool blending_)
{
   try
      {
         static_cast<T*>(self->this_)->blending_enable_set(::efl::eolian::to_cxx<bool>(blending_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_3D_Material * _evas_3d_mesh_frame_material_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_)
{
   Evas_3D_Material * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->frame_material_get(frame_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_frame_material_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int frame_, Evas_3D_Material * material_)
{
   try
      {
         static_cast<T*>(self->this_)->frame_material_set(frame_, material_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_3D_Vertex_Assembly _evas_3d_mesh_vertex_assembly_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_3D_Vertex_Assembly _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->vertex_assembly_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void _evas_3d_mesh_vertex_assembly_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_3D_Vertex_Assembly assembly_)
{
   try
      {
         static_cast<T*>(self->this_)->vertex_assembly_set(assembly_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas_3d_mesh >
{
   template <typename T>
   struct type
         : virtual operations< ::evas_3d_object >::template type<T>
         , virtual operations< ::evas::common_interface >::template type<T>
         , virtual operations< ::efl::file >::template type<T>
   {
      virtual void mmap_set(Eina_File * file_, ::efl::eina::optional< std::string > key_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_mmap_set(file_, ::efl::eolian::to_c(key_)));
      }

      virtual void frame_vertex_data_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_vertex_data_set(frame_, attrib_, stride_, data_));
      }

      virtual void frame_vertex_data_copy_set(int frame_, Evas_3D_Vertex_Attrib attrib_, int stride_, const void * data_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_vertex_data_copy_set(frame_, attrib_, stride_, data_));
      }

      virtual void * frame_vertex_data_map(int frame_, Evas_3D_Vertex_Attrib attrib_)
      {
         void * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_frame_vertex_data_map(frame_, attrib_));
            return _tmp_ret;
      }

      virtual void frame_vertex_data_unmap(int frame_, Evas_3D_Vertex_Attrib attrib_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_vertex_data_unmap(frame_, attrib_));
      }

      virtual int frame_vertex_stride_get(int frame_, Evas_3D_Vertex_Attrib attrib_)
      {
         int _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_frame_vertex_stride_get(frame_, attrib_));
            return _tmp_ret;
      }

      virtual void index_data_set(Evas_3D_Index_Format format_, int count_, const void * indices_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_index_data_set(format_, count_, indices_));
      }

      virtual void index_data_copy_set(Evas_3D_Index_Format format_, int count_, const void * indices_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_index_data_copy_set(format_, count_, indices_));
      }

      virtual Evas_3D_Index_Format index_format_get()
      {
         Evas_3D_Index_Format _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_index_format_get());
            return _tmp_ret;
      }

      virtual int index_count_get()
      {
         int _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_index_count_get());
            return _tmp_ret;
      }

      virtual void * index_data_map()
      {
         void * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_index_data_map());
            return _tmp_ret;
      }

      virtual void index_data_unmap()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_index_data_unmap());
      }

      virtual void frame_add(int frame_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_add(frame_));
      }

      virtual void frame_del(int frame_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_del(frame_));
      }

      virtual void vertex_count_set(unsigned int count_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_vertex_count_set(count_));
      }

      virtual int vertex_count_get()
      {
         int _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_vertex_count_get());
            return _tmp_ret;
      }

      virtual void fog_color_set(Evas_Real r_, Evas_Real g_, Evas_Real b_, Evas_Real a_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_fog_color_set(r_, g_, b_, a_));
      }

      virtual void fog_color_get(Evas_Real* r_, Evas_Real* g_, Evas_Real* b_, Evas_Real* a_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_fog_color_get(r_, g_, b_, a_));
      }

      virtual void blending_func_set(Evas_3D_Blend_Func sfactor_, Evas_3D_Blend_Func dfactor_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_blending_func_set(sfactor_, dfactor_));
      }

      virtual void blending_func_get(Evas_3D_Blend_Func* sfactor_, Evas_3D_Blend_Func* dfactor_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_blending_func_get(sfactor_, dfactor_));
      }

      virtual void fog_enable_set(bool enabled_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_fog_enable_set(::efl::eolian::to_c(enabled_)));
      }

      virtual bool fog_enable_get()
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_fog_enable_get());
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual Evas_3D_Shade_Mode shade_mode_get()
      {
         Evas_3D_Shade_Mode _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_shade_mode_get());
            return _tmp_ret;
      }

      virtual void shade_mode_set(Evas_3D_Shade_Mode mode_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_shade_mode_set(mode_));
      }

      virtual bool blending_enable_get()
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_blending_enable_get());
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void blending_enable_set(bool blending_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_blending_enable_set(::efl::eolian::to_c(blending_)));
      }

      virtual Evas_3D_Material * frame_material_get(int frame_)
      {
         Evas_3D_Material * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_frame_material_get(frame_));
            return _tmp_ret;
      }

      virtual void frame_material_set(int frame_, Evas_3D_Material * material_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_frame_material_set(frame_, material_));
      }

      virtual Evas_3D_Vertex_Assembly vertex_assembly_get()
      {
         Evas_3D_Vertex_Assembly _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_3d_mesh_vertex_assembly_get());
            return _tmp_ret;
      }

      virtual void vertex_assembly_set(Evas_3D_Vertex_Assembly assembly_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_3d_mesh_vertex_assembly_set(assembly_));
      }

   };
};


template<>
struct operation_description_class_size< ::evas_3d_mesh >
{
   static const int value = 30 + operation_description_class_size<::evas_3d_object >::value + operation_description_class_size<::evas::common_interface >::value + operation_description_class_size<::efl::file >::value;
};

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas_3d_mesh>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_mmap_set_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_mmap_set);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_vertex_data_set_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_vertex_data_set);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_vertex_data_copy_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_vertex_data_copy_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_vertex_data_map_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_vertex_data_map);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_vertex_data_unmap_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_vertex_data_unmap);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_vertex_stride_get_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_vertex_stride_get);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_data_set_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_data_set);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_data_copy_set_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_data_copy_set);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_format_get_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_format_get);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_count_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_count_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_data_map_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_data_map);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_index_data_unmap_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_index_data_unmap);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_add_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_add);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_del_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_del);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_vertex_count_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_vertex_count_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_vertex_count_get_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_vertex_count_get);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_fog_color_set_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_fog_color_set);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_fog_color_get_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_fog_color_get);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_blending_func_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_blending_func_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_blending_func_get_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_blending_func_get);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_fog_enable_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_fog_enable_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_fog_enable_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_fog_enable_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_shade_mode_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_shade_mode_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_shade_mode_set_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_shade_mode_set);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_blending_enable_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_blending_enable_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_blending_enable_set_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_blending_enable_set);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   ops[26].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_material_get_wrapper<T>);
   ops[26].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_material_get);
   ops[26].op = EO_OP_OVERRIDE;
   ops[26].op_type = EO_OP_TYPE_REGULAR;
   ops[26].doc = NULL;

   ops[27].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_frame_material_set_wrapper<T>);
   ops[27].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_frame_material_set);
   ops[27].op = EO_OP_OVERRIDE;
   ops[27].op_type = EO_OP_TYPE_REGULAR;
   ops[27].doc = NULL;

   ops[28].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_vertex_assembly_get_wrapper<T>);
   ops[28].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_vertex_assembly_get);
   ops[28].op = EO_OP_OVERRIDE;
   ops[28].op_type = EO_OP_TYPE_REGULAR;
   ops[28].doc = NULL;

   ops[29].func = reinterpret_cast<void*>(& ::_evas_3d_mesh_vertex_assembly_set_wrapper<T>);
   ops[29].api_func = reinterpret_cast<void*>(& ::evas_3d_mesh_vertex_assembly_set);
   ops[29].op = EO_OP_OVERRIDE;
   ops[29].op_type = EO_OP_TYPE_REGULAR;
   ops[29].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas_3d_object>(), &ops[30]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::common_interface>(), &ops[30 + operation_description_class_size<::evas_3d_object>::value]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::efl::file>(), &ops[30 + operation_description_class_size<::evas_3d_object>::value + operation_description_class_size<::evas::common_interface>::value]);
   return 0;
}
inline void
call_constructor(::efl::eo::detail::tag< ::evas_3d_mesh >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               ::efl::eo::detail::args_class<::evas_3d_mesh, ::std::tuple<::efl::eo::parent_type> > const& args)
{
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

inline Eo_Class const* get_eo_class(tag<::evas_3d_mesh>)
{
   return (EVAS_3D_MESH_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_3D_MESH_HH

