#ifndef EFL_GENERATED_EVAS_OBJECT_SMART_HH
#define EFL_GENERATED_EVAS_OBJECT_SMART_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_object_smart.eo.h"
}

#include "evas_object.eo.hh"
#include "evas_signal_interface.eo.hh"
#include <canvas/evas_object.eo.hh>
#include <string>

namespace evas {

struct object_smart;

}

namespace eo_cxx {

namespace evas {

struct object_smart
{
   /// @brief No description supplied by the EAPI.
   ///
   void show() const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param x 
   /// @param y 
   ///
   void move(Evas_Coord x_, Evas_Coord y_) const;


   /// @brief Set an smart object @b instance's smart callbacks descriptions.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE on failure.
   ///
   /// These descriptions are hints to be used by introspection and are
   /// not enforced in any way.
   ///
   /// It will not be checked if instance callbacks descriptions have the
   /// same name as respective possibly registered in the smart object
   /// @b class. Both are kept in different arrays and users of
   /// evas_object_smart_callbacks_descriptions_get() should handle this
   /// case as they wish.
   ///
   /// @note Becase @p descriptions must be @c NULL terminated, and
   /// because a @c NULL name makes little sense, too,
   /// Evas_Smart_Cb_Description.name must @b not be @c NULL.
   ///
   /// @note While instance callbacks descriptions are possible, they are
   /// @b not recommended. Use @b class callbacks descriptions
   /// instead as they make you smart object user's life simpler and
   /// will use less memory, as descriptions and arrays will be
   /// shared among all instances.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param descriptions @c NULL terminated array with
   /// #Evas_Smart_Cb_Description descriptions. Array elements won't be
   /// modified at run time, but references to them and their contents
   /// will be made, so this array should be kept alive during the whole
   /// object's lifetime.
   ///
   bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_) const;


   /// @brief Retrieve an smart object's know smart callback descriptions (both
   /// instance and class ones).
   ///
   /// This call searches for registered callback descriptions for both
   /// instance and class of the given smart object. These arrays will be
   /// sorted by Evas_Smart_Cb_Description.name and also @c NULL
   /// terminated, so both @a class_count and @a instance_count can be
   /// ignored, if the caller wishes so. The terminator @c NULL is not
   /// counted in these values.
   ///
   /// @note If just class descriptions are of interest, try
   /// evas_smart_callbacks_descriptions_get() instead.
   ///
   /// @note Use @c NULL pointers on the descriptions/counters you're not
   /// interested in: they'll be ignored by the function.
   ///
   /// @see evas_smart_callbacks_descriptions_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param[out] class_descriptions Where to store class callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned
   /// @param[out] class_count Returns how many class callbacks descriptions
   /// are known.
   /// @param[out] instance_descriptions Where to store instance callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned.
   /// @param[out] instance_count Returns how many instance callbacks
   /// descriptions are known.
   ///
   void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_) const;


   /// @brief Retrieves an iterator of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the iterator of the member objects of @p obj.
   ///
   /// @since 1.8
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   Eina_Iterator * iterator_new() const;


   /// @brief Find callback description for callback called @a name.
   ///
   /// or @c NULL if not found. If parameter is @c NULL, no search
   /// will be done on instance descriptions.
   /// @return reference to description if found, @c NULL if not found.
   ///
   /// @param name name of desired callback, must @b not be @c NULL.  The
   /// search have a special case for @a name being the same
   /// pointer as registered with Evas_Smart_Cb_Description, one
   /// can use it to avoid excessive use of strcmp().
   /// @param[out] class_description pointer to return class description or
   /// @c NULL if not found. If parameter is @c NULL, no search will
   /// be done on class descriptions.
   /// @param[out] instance_description pointer to return instance description
   ///
   void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_) const;


   /// @brief No description supplied by the EAPI.
   ///
   void hide() const;


   /// @brief Call the @b calculate() smart function immediately on a given smart
   /// object.
   ///
   /// This will force immediate calculations (see #Evas_Smart_Class)
   /// needed for renderization of this object and, besides, unset the
   /// flag on it telling it needs recalculation for the next rendering
   /// phase.
   ///
   /// @see evas_object_smart_need_recalculate_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void calculate() const;


   /// @brief Instantiates a new smart object described by @p s.
   ///
   /// @return a new #Evas_Object handle
   ///
   /// This is the function one should use when defining the public
   /// function @b adding an instance of the new smart object to a given
   /// canvas. It will take care of setting all of its internals to work
   /// as they should, if the user set things properly, as seem on the
   /// #EVAS_SMART_SUBCLASS_NEW, for example.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void add() const;


   /// @brief Set an Evas object as a member of a given smart object.
   ///
   /// Members will automatically be stacked and layered together with the
   /// smart object. The various stacking functions will operate on
   /// members relative to the other members instead of the entire canvas,
   /// since they now live on an exclusive layer (see
   /// evas_object_stack_above(), for more details).
   ///
   /// Any @p smart_obj object's specific implementation of the @c
   /// member_add() smart function will take place too, naturally.
   ///
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param sub_obj The member object
   ///
   void member_add(::evas::object sub_obj_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param w 
   /// @param h 
   ///
   void resize(Evas_Coord w_, Evas_Coord h_) const;


   /// @brief No description supplied by the EAPI.
   ///
   void clip_unset() const;


   /// @brief Mark smart object as changed, dirty.
   ///
   /// This will flag the given object as needing recalculation,
   /// forcefully. As an effect, on the next rendering cycle its @b
   /// calculate() (see #Evas_Smart_Class) smart function will be called.
   ///
   /// @see evas_object_smart_need_recalculate_set().
   /// @see evas_object_smart_calculate().
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void changed() const;


   /// @brief Removes a member object from a given smart object.
   ///
   /// This removes a member object from a smart object, if it was added
   /// to any. The object will still be on the canvas, but no longer
   /// associated with whichever smart object it was associated with.
   ///
   /// @see evas_object_smart_member_add() for more details
   /// @see evas_object_smart_members_get()
   ///
   /// @param sub_obj the member object
   /// @ingroup Evas_Smart_Object_Group
   ///
   void member_del(::efl::eina::optional< ::evas::object > sub_obj_) const;


   /// @brief Deletes a smart object.
   ///
   void del() const;


   /// @brief Attach a given smart data to a given smart object.
   ///
   /// @param s 
   ///
   void attach(Evas_Smart * s_) const;


   /// @brief Get the value of the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// @return if flag is set or not.
   ///
   /// @note this flag will be unset during the rendering phase, when the
   /// @c calculate() smart function is called, if one is provided.
   /// If it's not provided, then the flag will be left unchanged
   /// after the rendering phase.
   ///
   /// @see evas_object_smart_need_recalculate_set(), for more details
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   bool need_recalculate_get() const;


   /// @brief Set or unset the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// If this flag is set, then the @c calculate() smart function of @p
   /// obj will be called, if one is provided, during rendering phase of
   /// Evas (see evas_render()), after which this flag will be
   /// automatically unset.
   ///
   /// If that smart function is not provided for the given object, this
   /// flag will be left unchanged.
   ///
   /// @note just setting this flag will not make the canvas' whole scene
   /// dirty, by itself, and evas_render() will have no effect. To
   /// force that, use evas_object_smart_changed(), that will also
   /// call this function automatically, with @c EINA_TRUE as parameter.
   ///
   /// @see evas_object_smart_need_recalculate_get()
   /// @see evas_object_smart_calculate()
   /// @see evas_smart_objects_calculate()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   void need_recalculate_set(bool value_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param clip 
   ///
   void clip_set(::efl::eina::optional< ::evas::object > clip_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param r 
   /// @param g 
   /// @param b 
   /// @param a 
   ///
   void color_set(int r_, int g_, int b_, int a_) const;


   /// @brief Store a pointer to user data for a given smart object.
   ///
   /// This data is stored @b independently of the one set by
   /// evas_object_data_set(), naturally.
   ///
   /// @see evas_object_smart_data_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param data A pointer to user data
   ///
   void data_set(void * data_) const;


   /// @brief Retrieves the list of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the list of the member objects of @p obj.
   ///
   /// The returned list should be freed with @c eina_list_free() when you
   /// no longer need it.
   ///
   /// @since 1.7 This function will return @c NULL when a non-smart object is passed.
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_iterator_new()
   ///
   ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > members_get() const;


   /// @brief Get the #Evas_Smart from which @p obj smart object was created.
   ///
   /// @return the #Evas_Smart handle or @c NULL, on errors
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   Evas_Smart * smart_get() const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJECT_SMART_CLASS);
   }

   operator ::evas::object_smart() const;
   operator ::evas::object_smart&();
   operator ::evas::object_smart const&() const;

   template <typename D>
   struct address_of
   {
      operator ::evas::object_smart*() const { return static_cast<::evas::object_smart*>(static_cast<D const*>(this)->p); }
      operator ::evas::object_smart const*() const { return static_cast<::evas::object_smart const*>(static_cast<D const*>(this)->p); }
   };

   template <typename D>
   struct address_const_of
   {
      operator ::evas::object_smart const*() const { return static_cast<::evas::object_smart const*>(static_cast<D const*>(this)->p); }
   };

private:
   Eo* _concrete_eo_ptr() const
   {
      return static_cast<::efl::eo::concrete const*>(static_cast<void const*>(this))->_eo_ptr();
   }

};

}

}

namespace evas {

struct object_smart
      : ::efl::eo::concrete
      , ::eo_cxx::eo::base
      , ::eo_cxx::evas::common_interface
      , ::eo_cxx::evas::object
      , ::eo_cxx::evas::signal_interface
{
   object_smart(::efl::eo::parent_type _p = (::efl::eo::parent = nullptr))
      : object_smart(_ctors_call(_p))
   {}

   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit object_smart(Eo* eo)
      : ::efl::eo::concrete(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit object_smart(std::nullptr_t)
      : ::efl::eo::concrete(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   object_smart(object_smart const& other)
      : object_smart(eo_ref(other._eo_ptr()))
   {}

   ~object_smart() {}

   /// @brief No description supplied by the EAPI.
   ///
   void show() const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param x 
   /// @param y 
   ///
   void move(Evas_Coord x_, Evas_Coord y_) const;


   /// @brief Set an smart object @b instance's smart callbacks descriptions.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE on failure.
   ///
   /// These descriptions are hints to be used by introspection and are
   /// not enforced in any way.
   ///
   /// It will not be checked if instance callbacks descriptions have the
   /// same name as respective possibly registered in the smart object
   /// @b class. Both are kept in different arrays and users of
   /// evas_object_smart_callbacks_descriptions_get() should handle this
   /// case as they wish.
   ///
   /// @note Becase @p descriptions must be @c NULL terminated, and
   /// because a @c NULL name makes little sense, too,
   /// Evas_Smart_Cb_Description.name must @b not be @c NULL.
   ///
   /// @note While instance callbacks descriptions are possible, they are
   /// @b not recommended. Use @b class callbacks descriptions
   /// instead as they make you smart object user's life simpler and
   /// will use less memory, as descriptions and arrays will be
   /// shared among all instances.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param descriptions @c NULL terminated array with
   /// #Evas_Smart_Cb_Description descriptions. Array elements won't be
   /// modified at run time, but references to them and their contents
   /// will be made, so this array should be kept alive during the whole
   /// object's lifetime.
   ///
   bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_) const;


   /// @brief Retrieve an smart object's know smart callback descriptions (both
   /// instance and class ones).
   ///
   /// This call searches for registered callback descriptions for both
   /// instance and class of the given smart object. These arrays will be
   /// sorted by Evas_Smart_Cb_Description.name and also @c NULL
   /// terminated, so both @a class_count and @a instance_count can be
   /// ignored, if the caller wishes so. The terminator @c NULL is not
   /// counted in these values.
   ///
   /// @note If just class descriptions are of interest, try
   /// evas_smart_callbacks_descriptions_get() instead.
   ///
   /// @note Use @c NULL pointers on the descriptions/counters you're not
   /// interested in: they'll be ignored by the function.
   ///
   /// @see evas_smart_callbacks_descriptions_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param[out] class_descriptions Where to store class callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned
   /// @param[out] class_count Returns how many class callbacks descriptions
   /// are known.
   /// @param[out] instance_descriptions Where to store instance callbacks
   /// descriptions array, if any is known. If no descriptions are
   /// known, @c NULL is returned.
   /// @param[out] instance_count Returns how many instance callbacks
   /// descriptions are known.
   ///
   void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_) const;


   /// @brief Retrieves an iterator of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the iterator of the member objects of @p obj.
   ///
   /// @since 1.8
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   Eina_Iterator * iterator_new() const;


   /// @brief Find callback description for callback called @a name.
   ///
   /// or @c NULL if not found. If parameter is @c NULL, no search
   /// will be done on instance descriptions.
   /// @return reference to description if found, @c NULL if not found.
   ///
   /// @param name name of desired callback, must @b not be @c NULL.  The
   /// search have a special case for @a name being the same
   /// pointer as registered with Evas_Smart_Cb_Description, one
   /// can use it to avoid excessive use of strcmp().
   /// @param[out] class_description pointer to return class description or
   /// @c NULL if not found. If parameter is @c NULL, no search will
   /// be done on class descriptions.
   /// @param[out] instance_description pointer to return instance description
   ///
   void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_) const;


   /// @brief No description supplied by the EAPI.
   ///
   void hide() const;


   /// @brief Call the @b calculate() smart function immediately on a given smart
   /// object.
   ///
   /// This will force immediate calculations (see #Evas_Smart_Class)
   /// needed for renderization of this object and, besides, unset the
   /// flag on it telling it needs recalculation for the next rendering
   /// phase.
   ///
   /// @see evas_object_smart_need_recalculate_set()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void calculate() const;


   /// @brief Instantiates a new smart object described by @p s.
   ///
   /// @return a new #Evas_Object handle
   ///
   /// This is the function one should use when defining the public
   /// function @b adding an instance of the new smart object to a given
   /// canvas. It will take care of setting all of its internals to work
   /// as they should, if the user set things properly, as seem on the
   /// #EVAS_SMART_SUBCLASS_NEW, for example.
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void add() const;


   /// @brief Set an Evas object as a member of a given smart object.
   ///
   /// Members will automatically be stacked and layered together with the
   /// smart object. The various stacking functions will operate on
   /// members relative to the other members instead of the entire canvas,
   /// since they now live on an exclusive layer (see
   /// evas_object_stack_above(), for more details).
   ///
   /// Any @p smart_obj object's specific implementation of the @c
   /// member_add() smart function will take place too, naturally.
   ///
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_members_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param sub_obj The member object
   ///
   void member_add(::evas::object sub_obj_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param w 
   /// @param h 
   ///
   void resize(Evas_Coord w_, Evas_Coord h_) const;


   /// @brief No description supplied by the EAPI.
   ///
   void clip_unset() const;


   /// @brief Mark smart object as changed, dirty.
   ///
   /// This will flag the given object as needing recalculation,
   /// forcefully. As an effect, on the next rendering cycle its @b
   /// calculate() (see #Evas_Smart_Class) smart function will be called.
   ///
   /// @see evas_object_smart_need_recalculate_set().
   /// @see evas_object_smart_calculate().
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   void changed() const;


   /// @brief Removes a member object from a given smart object.
   ///
   /// This removes a member object from a smart object, if it was added
   /// to any. The object will still be on the canvas, but no longer
   /// associated with whichever smart object it was associated with.
   ///
   /// @see evas_object_smart_member_add() for more details
   /// @see evas_object_smart_members_get()
   ///
   /// @param sub_obj the member object
   /// @ingroup Evas_Smart_Object_Group
   ///
   void member_del(::efl::eina::optional< ::evas::object > sub_obj_) const;


   /// @brief Deletes a smart object.
   ///
   void del() const;


   /// @brief Attach a given smart data to a given smart object.
   ///
   /// @param s 
   ///
   void attach(Evas_Smart * s_) const;


   /// @brief Get the value of the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// @return if flag is set or not.
   ///
   /// @note this flag will be unset during the rendering phase, when the
   /// @c calculate() smart function is called, if one is provided.
   /// If it's not provided, then the flag will be left unchanged
   /// after the rendering phase.
   ///
   /// @see evas_object_smart_need_recalculate_set(), for more details
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   bool need_recalculate_get() const;


   /// @brief Set or unset the flag signalling that a given smart object needs to
   /// get recalculated.
   ///
   /// If this flag is set, then the @c calculate() smart function of @p
   /// obj will be called, if one is provided, during rendering phase of
   /// Evas (see evas_render()), after which this flag will be
   /// automatically unset.
   ///
   /// If that smart function is not provided for the given object, this
   /// flag will be left unchanged.
   ///
   /// @note just setting this flag will not make the canvas' whole scene
   /// dirty, by itself, and evas_render() will have no effect. To
   /// force that, use evas_object_smart_changed(), that will also
   /// call this function automatically, with @c EINA_TRUE as parameter.
   ///
   /// @see evas_object_smart_need_recalculate_get()
   /// @see evas_object_smart_calculate()
   /// @see evas_smart_objects_calculate()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param value whether one wants to set (@c EINA_TRUE) or to unset
   /// (@c EINA_FALSE) the flag.
   ///
   void need_recalculate_set(bool value_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param clip 
   ///
   void clip_set(::efl::eina::optional< ::evas::object > clip_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param r 
   /// @param g 
   /// @param b 
   /// @param a 
   ///
   void color_set(int r_, int g_, int b_, int a_) const;


   /// @brief Store a pointer to user data for a given smart object.
   ///
   /// This data is stored @b independently of the one set by
   /// evas_object_data_set(), naturally.
   ///
   /// @see evas_object_smart_data_get()
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   /// @param data A pointer to user data
   ///
   void data_set(void * data_) const;


   /// @brief Retrieves the list of the member objects of a given Evas smart
   /// object
   ///
   /// @return Returns the list of the member objects of @p obj.
   ///
   /// The returned list should be freed with @c eina_list_free() when you
   /// no longer need it.
   ///
   /// @since 1.7 This function will return @c NULL when a non-smart object is passed.
   ///
   /// @see evas_object_smart_member_add()
   /// @see evas_object_smart_member_del()
   /// @see evas_object_smart_iterator_new()
   ///
   ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > members_get() const;


   /// @brief Get the #Evas_Smart from which @p obj smart object was created.
   ///
   /// @return the #Evas_Smart handle or @c NULL, on errors
   ///
   /// @ingroup Evas_Smart_Object_Group
   ///
   Evas_Smart * smart_get() const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_OBJECT_SMART_CLASS);
   }

   struct address_of
      : ::eo_cxx::evas::object_smart::address_of<address_of>
      , ::eo_cxx::eo::base::address_of<address_of>
      , ::eo_cxx::evas::common_interface::address_of<address_of>
      , ::eo_cxx::evas::object::address_of<address_of>
      , ::eo_cxx::evas::signal_interface::address_of<address_of>
      , ::efl::eo::detail::concrete_address_of
   {
      explicit address_of(::evas::object_smart* p)
         : ::efl::eo::detail::concrete_address_of(p)
      {}
   };
   address_of operator&() { return address_of(this); }

   struct address_const_of
      : ::eo_cxx::evas::object_smart::address_const_of<address_const_of>
      , ::eo_cxx::eo::base::address_const_of<address_const_of>
      , ::eo_cxx::evas::common_interface::address_const_of<address_const_of>
      , ::eo_cxx::evas::object::address_const_of<address_const_of>
      , ::eo_cxx::evas::signal_interface::address_const_of<address_const_of>
      , ::efl::eo::detail::concrete_address_const_of
   {
      explicit address_const_of(::evas::object_smart const* p)
         : ::efl::eo::detail::concrete_address_const_of(p)
      {}
   };
   address_const_of operator&() const { return address_const_of(this); }

private:
   static Eo* _ctors_call(::efl::eo::parent_type _p)
   {
      Eo* _ret_eo = eo_add_ref(EVAS_OBJECT_SMART_CLASS, _p._eo_raw, );

      return _ret_eo;
   }

      Eo* _concrete_eo_ptr() const { return _eo_ptr(); }
};

static_assert(sizeof(::evas::object_smart) == sizeof(Eo*), "");
static_assert(std::is_standard_layout<::evas::object_smart>::value, "");

}

inline void evas::object_smart::show() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_show());
}


inline void evas::object_smart::move(Evas_Coord x_, Evas_Coord y_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_move(x_, y_));
}


inline bool evas::object_smart::callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::object_smart::callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
}


inline Eina_Iterator * evas::object_smart::iterator_new() const
{
   Eina_Iterator * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
   return _tmp_ret;
}


inline void evas::object_smart::callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_callback_description_find(::efl::eolian::to_c(name_), class_description_, instance_description_));
}


inline void evas::object_smart::hide() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_hide());
}


inline void evas::object_smart::calculate() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_calculate());
}


inline void evas::object_smart::add() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_add());
}


inline void evas::object_smart::member_add(::evas::object sub_obj_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_member_add(::efl::eolian::to_c(sub_obj_)));
}


inline void evas::object_smart::resize(Evas_Coord w_, Evas_Coord h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
}


inline void evas::object_smart::clip_unset() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_clip_unset());
}


inline void evas::object_smart::changed() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_changed());
}


inline void evas::object_smart::member_del(::efl::eina::optional< ::evas::object > sub_obj_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_member_del(::efl::eolian::to_c(sub_obj_)));
}


inline void evas::object_smart::del() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_del());
}


inline void evas::object_smart::attach(Evas_Smart * s_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_attach(s_));
}


inline bool evas::object_smart::need_recalculate_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::object_smart::need_recalculate_set(bool value_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_need_recalculate_set(::efl::eolian::to_c(value_)));
}


inline void evas::object_smart::clip_set(::efl::eina::optional< ::evas::object > clip_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_clip_set(::efl::eolian::to_c(clip_)));
}


inline void evas::object_smart::color_set(int r_, int g_, int b_, int a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_color_set(r_, g_, b_, a_));
}


inline void evas::object_smart::data_set(void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_data_set(data_));
}


inline ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > evas::object_smart::members_get() const
{
   Eina_List * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::range_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
}


inline Evas_Smart * evas::object_smart::smart_get() const
{
   Evas_Smart * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_get());
   return _tmp_ret;
}


inline void eo_cxx::evas::object_smart::show() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_show());
}


inline void eo_cxx::evas::object_smart::move(Evas_Coord x_, Evas_Coord y_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_move(x_, y_));
}


inline bool eo_cxx::evas::object_smart::callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::object_smart::callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
}


inline Eina_Iterator * eo_cxx::evas::object_smart::iterator_new() const
{
   Eina_Iterator * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_iterator_new());
   return _tmp_ret;
}


inline void eo_cxx::evas::object_smart::callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_callback_description_find(::efl::eolian::to_c(name_), class_description_, instance_description_));
}


inline void eo_cxx::evas::object_smart::hide() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_hide());
}


inline void eo_cxx::evas::object_smart::calculate() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_calculate());
}


inline void eo_cxx::evas::object_smart::add() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_add());
}


inline void eo_cxx::evas::object_smart::member_add(::evas::object sub_obj_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_member_add(::efl::eolian::to_c(sub_obj_)));
}


inline void eo_cxx::evas::object_smart::resize(Evas_Coord w_, Evas_Coord h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_resize(w_, h_));
}


inline void eo_cxx::evas::object_smart::clip_unset() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_clip_unset());
}


inline void eo_cxx::evas::object_smart::changed() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_changed());
}


inline void eo_cxx::evas::object_smart::member_del(::efl::eina::optional< ::evas::object > sub_obj_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_member_del(::efl::eolian::to_c(sub_obj_)));
}


inline void eo_cxx::evas::object_smart::del() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_del());
}


inline void eo_cxx::evas::object_smart::attach(Evas_Smart * s_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_attach(s_));
}


inline bool eo_cxx::evas::object_smart::need_recalculate_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_need_recalculate_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::object_smart::need_recalculate_set(bool value_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_need_recalculate_set(::efl::eolian::to_c(value_)));
}


inline void eo_cxx::evas::object_smart::clip_set(::efl::eina::optional< ::evas::object > clip_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_clip_set(::efl::eolian::to_c(clip_)));
}


inline void eo_cxx::evas::object_smart::color_set(int r_, int g_, int b_, int a_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_color_set(r_, g_, b_, a_));
}


inline void eo_cxx::evas::object_smart::data_set(void * data_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_smart_data_set(data_));
}


inline ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > eo_cxx::evas::object_smart::members_get() const
{
   Eina_List * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_members_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::range_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
}


inline Evas_Smart * eo_cxx::evas::object_smart::smart_get() const
{
   Evas_Smart * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_smart_get());
   return _tmp_ret;
}


inline ::eo_cxx::evas::object_smart::operator ::evas::object_smart() const
{
   return *static_cast<::evas::object_smart const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas::object_smart::operator ::evas::object_smart&()
{
   return *static_cast<::evas::object_smart*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas::object_smart::operator ::evas::object_smart const&() const
{
   return *static_cast<::evas::object_smart const*>(static_cast<void const*>(this));
}

template <typename T>
void evas_object_smart_show_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->show();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_move_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Coord x_, Evas_Coord y_)
{
   try
      {
         static_cast<T*>(self->this_)->move(x_, y_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool evas_object_smart_callbacks_descriptions_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description * descriptions_)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->callbacks_descriptions_set(descriptions_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_object_smart_callbacks_descriptions_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_)
{
   try
      {
         static_cast<T*>(self->this_)->callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Eina_Iterator * evas_object_smart_iterator_new_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Eina_Iterator * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->iterator_new();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_object_smart_callback_description_find_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_)
{
   try
      {
         static_cast<T*>(self->this_)->callback_description_find(::efl::eolian::to_cxx<std::string>(name_, std::tuple<std::false_type>()), class_description_, instance_description_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_hide_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->hide();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_calculate_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->calculate();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_add_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->add();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_member_add_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj_)
{
   try
      {
         static_cast<T*>(self->this_)->member_add(::efl::eolian::to_cxx<::evas::object>(sub_obj_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_resize_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Coord w_, Evas_Coord h_)
{
   try
      {
         static_cast<T*>(self->this_)->resize(w_, h_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_clip_unset_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->clip_unset();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_changed_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->changed();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_member_del_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Object * sub_obj_)
{
   try
      {
         static_cast<T*>(self->this_)->member_del(::efl::eolian::to_cxx<::efl::eina::optional< ::evas::object >>(sub_obj_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_del_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->del();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_attach_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Smart * s_)
{
   try
      {
         static_cast<T*>(self->this_)->attach(s_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool evas_object_smart_need_recalculate_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->need_recalculate_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_object_smart_need_recalculate_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_Bool value_)
{
   try
      {
         static_cast<T*>(self->this_)->need_recalculate_set(::efl::eolian::to_cxx<bool>(value_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_clip_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Object * clip_)
{
   try
      {
         static_cast<T*>(self->this_)->clip_set(::efl::eolian::to_cxx<::efl::eina::optional< ::evas::object >>(clip_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_color_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int r_, int g_, int b_, int a_)
{
   try
      {
         static_cast<T*>(self->this_)->color_set(r_, g_, b_, a_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_object_smart_data_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, void * data_)
{
   try
      {
         static_cast<T*>(self->this_)->data_set(data_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > evas_object_smart_members_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->members_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
Evas_Smart * evas_object_smart_smart_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_Smart * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->smart_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas::object_smart >
{
   template <typename T>
   struct type
         : virtual operations< ::evas::object >::template type<T>
         , virtual operations< ::evas::signal_interface >::template type<T>
   {
      virtual void show()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_show());
      }

      virtual void move(Evas_Coord x_, Evas_Coord y_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_move(x_, y_));
      }

      virtual bool callbacks_descriptions_set(const Evas_Smart_Cb_Description * descriptions_)
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_callbacks_descriptions_set(descriptions_));
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void callbacks_descriptions_get(const Evas_Smart_Cb_Description *** class_descriptions_, unsigned int* class_count_, const Evas_Smart_Cb_Description *** instance_descriptions_, unsigned int* instance_count_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_callbacks_descriptions_get(class_descriptions_, class_count_, instance_descriptions_, instance_count_));
      }

      virtual Eina_Iterator * iterator_new()
      {
         Eina_Iterator * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_iterator_new());
            return _tmp_ret;
      }

      virtual void callback_description_find(std::string name_, const Evas_Smart_Cb_Description ** class_description_, const Evas_Smart_Cb_Description ** instance_description_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_callback_description_find(::efl::eolian::to_c(name_), class_description_, instance_description_));
      }

      virtual void hide()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_hide());
      }

      virtual void calculate()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_calculate());
      }

      virtual void add()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_add());
      }

      virtual void member_add(::evas::object sub_obj_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_member_add(::efl::eolian::to_c(sub_obj_)));
      }

      virtual void resize(Evas_Coord w_, Evas_Coord h_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_resize(w_, h_));
      }

      virtual void clip_unset()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_clip_unset());
      }

      virtual void changed()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_changed());
      }

      virtual void member_del(::efl::eina::optional< ::evas::object > sub_obj_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_member_del(::efl::eolian::to_c(sub_obj_)));
      }

      virtual void del()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_del());
      }

      virtual void attach(Evas_Smart * s_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_attach(s_));
      }

      virtual bool need_recalculate_get()
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_need_recalculate_get());
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void need_recalculate_set(bool value_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_need_recalculate_set(::efl::eolian::to_c(value_)));
      }

      virtual void clip_set(::efl::eina::optional< ::evas::object > clip_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_clip_set(::efl::eolian::to_c(clip_)));
      }

      virtual void color_set(int r_, int g_, int b_, int a_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_color_set(r_, g_, b_, a_));
      }

      virtual void data_set(void * data_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_smart_data_set(data_));
      }

      virtual ::efl::eina::optional< ::efl::eina::range_list< ::evas::object > > members_get()
      {
         Eina_List * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_members_get());
            return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::range_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
      }

      virtual Evas_Smart * smart_get()
      {
         Evas_Smart * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_smart_get());
            return _tmp_ret;
      }

   };
};


template<>
struct operation_description_class_size< ::evas::object_smart >
{
   static const int value = 23 + operation_description_class_size<::evas::object >::value + operation_description_class_size<::evas::signal_interface >::value;
};

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas::object_smart>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_object_smart_show_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_show);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_object_smart_move_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_move);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_object_smart_callbacks_descriptions_set_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_set);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_object_smart_callbacks_descriptions_get_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callbacks_descriptions_get);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_object_smart_iterator_new_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_iterator_new);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_object_smart_callback_description_find_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_callback_description_find);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_object_smart_hide_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_hide);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_object_smart_calculate_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_calculate);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_object_smart_add_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_add);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_object_smart_member_add_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_add);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_object_smart_resize_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_resize);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_object_smart_clip_unset_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_unset);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_object_smart_changed_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_changed);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_object_smart_member_del_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_member_del);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_object_smart_del_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_del);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_object_smart_attach_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_attach);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_object_smart_need_recalculate_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_object_smart_need_recalculate_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_need_recalculate_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_object_smart_clip_set_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_clip_set);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_object_smart_color_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_color_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_object_smart_data_set_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_data_set);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_object_smart_members_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_members_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::evas_object_smart_smart_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_obj_smart_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::object>(), &ops[23]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::signal_interface>(), &ops[23 + operation_description_class_size<::evas::object>::value]);
   return 0;
}
inline void
call_constructor(::efl::eo::detail::tag< ::evas::object_smart >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               ::efl::eo::detail::args_class<::evas::object_smart, ::std::tuple<::efl::eo::parent_type> > const& args)
{
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

inline Eo_Class const* get_eo_class(tag<::evas::object_smart>)
{
   return (EVAS_OBJECT_SMART_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_OBJECT_SMART_HH

