#ifndef EFL_GENERATED_EVAS_TEXTBLOCK_HH
#define EFL_GENERATED_EVAS_TEXTBLOCK_HH

extern "C"
{
#include <Efl.h>
}
#include <Eo.hh>

#include <eo_cxx_interop.hh>

extern "C"
{
#include "evas_textblock.eo.h"
}

#include "evas_object.eo.hh"
#include <string>

namespace evas {

struct textblock;

}

namespace eo_cxx {

namespace evas {

struct textblock
{
   /// @brief Get the geometry of a line number.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise.
   ///
   /// @param line the line number.
   /// @param[out] cx x coord of the line.
   /// @param[out] cy y coord of the line.
   /// @param[out] cw w coord of the line.
   /// @param[out] ch h coord of the line.
   ///
   bool line_number_geometry_get(int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_) const;


   /// @brief @brief Get the "replacement character" for given textblock object. Returns
   /// @c NULL if no replacement character is in use.
   ///
   /// @return Replacement character or @c NULL.
   ///
   ::efl::eina::optional< std::string > replace_char_get() const;


   /// @brief Del the from the top of the user style stack.
   ///
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   void style_user_pop() const;


   /// @brief Create a new cursor, associate it to the obj and init it to point
   /// to the start of the textblock. Association to the object means the cursor
   /// will be updated when the object will change.
   ///
   /// @note if you need speed and you know what you are doing, it's slightly faster to just allocate the cursor yourself and not associate it. (only people developing the actual object, and not users of the object).
   ///
   /// @return the new cursor.
   ///
   Evas_Textblock_Cursor * cursor_new() const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param anchor 
   ///
   ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > node_format_list_get(::efl::eina::optional< std::string > anchor_) const;


   /// @brief Get (don't remove) the style at the top of the user style stack.
   ///
   /// @return the style of the object.
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   const Evas_Textblock_Style * style_user_peek() const;


   /// @brief Remove a format node and its match.
   ///
   /// @param n 
   ///
   void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n_) const;


   /// @brief Clear the textblock object.
   /// @note Does *NOT* free the Evas object itself.
   ///
   /// @return nothing.
   ///
   void clear() const;


   /// @brief Push ts to the top of the user style stack.
   ///
   /// FIXME: API is solid but currently only supports 1 style in the stack.
   ///
   /// The user style overrides the corresponding elements of the regular style.
   /// This is the proper way to do theme overrides in code.
   /// @return Returns no value.
   /// @see evas_object_textblock_style_set
   /// @since 1.2
   ///
   /// @param ts the style to set.
   ///
   void style_user_push(Evas_Textblock_Style * ts_) const;


   /// @brief Return the markup of the object.
   ///
   /// @return the markup text of the object.
   ///
   /// @param text the markup text to use.
   ///
   ::efl::eina::optional< std::string > text_markup_get() const;


   /// @brief Sets the tetxblock's text to the markup text.
   ///
   /// @note assumes text does not include the unicode object replacement char (0xFFFC)
   ///
   /// @return Return no value.
   ///
   /// @param text the markup text to use.
   ///
   void text_markup_set(::efl::eina::optional< std::string > text_) const;


   /// @brief @brief Gets the vertical alignment of a textblock
   ///
   /// @return The alignment set for the object.
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   double valign_get() const;


   /// @brief @brief Sets the vertical alignment of text within the textblock object
   /// as a whole.
   ///
   /// Normally alignment is 0.0 (top of object). Values given should be
   /// between 0.0 and 1.0 (1.0 bottom of object, 0.5 being vertically centered
   /// etc.).
   ///
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   void valign_set(double align_) const;


   /// @brief @brief Gets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @return A null terminated string of delimiters, e.g ",|". If empty, returns
   /// @c NULL.
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   ::efl::eina::optional< std::string > bidi_delimiters_get() const;


   /// @brief @brief Sets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   void bidi_delimiters_set(::efl::eina::optional< std::string > delim_) const;


   /// @brief @brief Set the "replacement character" to use for the given textblock object.
   ///
   /// @param ch The charset name.
   ///
   void replace_char_set(::efl::eina::optional< std::string > ch_) const;


   /// @brief @brief Gets newline mode. When true, newline character behaves
   /// as a paragraph separator.
   ///
   /// @return @c EINA_TRUE if in legacy mode, @c EINA_FALSE otherwise.
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   bool legacy_newline_get() const;


   /// @brief @brief Sets newline mode. When true, newline character will behave
   /// as a paragraph separator.
   ///
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   void legacy_newline_set(bool mode_) const;


   /// @brief Return the style of an object.
   /// @return the style of the object.
   ///
   /// @param ts the style to set.
   ///
   const Evas_Textblock_Style * style_get() const;


   /// @brief Set the objects style to ts.
   /// @return Returns no value.
   ///
   /// @param ts the style to set.
   ///
   void style_set(const Evas_Textblock_Style * ts_) const;


   /// @brief Returns the first format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_first_get() const;


   /// @brief Get the formatted width and height. This calculates the actual size after restricting
   /// the textblock to the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_native_get
   /// is that the "native" function does not wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while this function gives the size after wrapping
   /// according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   ///
   /// @return Returns no value.
   /// @see evas_object_textblock_size_native_get
   ///
   /// @param w the width of the object.
   /// @param h the height of the object
   ///
   void size_formatted_get(Evas_Coord* w_, Evas_Coord* h_) const;


   /// @brief Returns the last format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_last_get() const;


   /// @brief Return the object's main cursor.
   ///
   /// @return The @p obj's main cursor.
   ///
   Evas_Textblock_Cursor * cursor_get() const;


   /// @brief Get the native width and height. This calculates the actual size without taking account
   /// the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_formatted_get
   /// is that the "native" function does not take wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while the "formatted" function gives the size after
   /// wrapping text according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   /// @return Returns no value.
   ///
   /// @param w the width returned
   /// @param h the height returned
   ///
   void size_native_get(Evas_Coord* w_, Evas_Coord* h_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param l 
   /// @param r 
   /// @param t 
   /// @param b 
   ///
   void style_insets_get(Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_TEXTBLOCK_CLASS);
   }

   operator ::evas::textblock() const;
   operator ::evas::textblock&();
   operator ::evas::textblock const&() const;

   template <typename D>
   struct address_of
   {
      operator ::evas::textblock*() const { return static_cast<::evas::textblock*>(static_cast<D const*>(this)->p); }
      operator ::evas::textblock const*() const { return static_cast<::evas::textblock const*>(static_cast<D const*>(this)->p); }
   };

   template <typename D>
   struct address_const_of
   {
      operator ::evas::textblock const*() const { return static_cast<::evas::textblock const*>(static_cast<D const*>(this)->p); }
   };

private:
   Eo* _concrete_eo_ptr() const
   {
      return static_cast<::efl::eo::concrete const*>(static_cast<void const*>(this))->_eo_ptr();
   }

};

}

}

namespace evas {

struct textblock
      : ::efl::eo::concrete
      , ::eo_cxx::eo::base
      , ::eo_cxx::evas::common_interface
      , ::eo_cxx::evas::object
{
   textblock(::efl::eo::parent_type _p = (::efl::eo::parent = nullptr))
      : textblock(_ctors_call(_p))
   {}

   /// @brief Eo Constructor.
   ///
   /// Constructs the object from an Eo* pointer stealing its ownership.
   ///
   /// @param eo The Eo object pointer.
   ///
   explicit textblock(Eo* eo)
      : ::efl::eo::concrete(eo)
   {}

   /// @brief nullptr_t Constructor.
   ///
   /// Constructs an empty (null) object.
   ///
   explicit textblock(std::nullptr_t)
      : ::efl::eo::concrete(nullptr)
   {}

   /// @brief Copy Constructor.
   ///
   textblock(textblock const& other)
      : textblock(eo_ref(other._eo_ptr()))
   {}

   ~textblock() {}

   /// @brief Get the geometry of a line number.
   ///
   /// @return @c EINA_TRUE on success, @c EINA_FALSE otherwise.
   ///
   /// @param line the line number.
   /// @param[out] cx x coord of the line.
   /// @param[out] cy y coord of the line.
   /// @param[out] cw w coord of the line.
   /// @param[out] ch h coord of the line.
   ///
   bool line_number_geometry_get(int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_) const;


   /// @brief @brief Get the "replacement character" for given textblock object. Returns
   /// @c NULL if no replacement character is in use.
   ///
   /// @return Replacement character or @c NULL.
   ///
   ::efl::eina::optional< std::string > replace_char_get() const;


   /// @brief Del the from the top of the user style stack.
   ///
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   void style_user_pop() const;


   /// @brief Create a new cursor, associate it to the obj and init it to point
   /// to the start of the textblock. Association to the object means the cursor
   /// will be updated when the object will change.
   ///
   /// @note if you need speed and you know what you are doing, it's slightly faster to just allocate the cursor yourself and not associate it. (only people developing the actual object, and not users of the object).
   ///
   /// @return the new cursor.
   ///
   Evas_Textblock_Cursor * cursor_new() const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param anchor 
   ///
   ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > node_format_list_get(::efl::eina::optional< std::string > anchor_) const;


   /// @brief Get (don't remove) the style at the top of the user style stack.
   ///
   /// @return the style of the object.
   /// @see evas_object_textblock_style_get
   /// @since 1.2
   ///
   const Evas_Textblock_Style * style_user_peek() const;


   /// @brief Remove a format node and its match.
   ///
   /// @param n 
   ///
   void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n_) const;


   /// @brief Clear the textblock object.
   /// @note Does *NOT* free the Evas object itself.
   ///
   /// @return nothing.
   ///
   void clear() const;


   /// @brief Push ts to the top of the user style stack.
   ///
   /// FIXME: API is solid but currently only supports 1 style in the stack.
   ///
   /// The user style overrides the corresponding elements of the regular style.
   /// This is the proper way to do theme overrides in code.
   /// @return Returns no value.
   /// @see evas_object_textblock_style_set
   /// @since 1.2
   ///
   /// @param ts the style to set.
   ///
   void style_user_push(Evas_Textblock_Style * ts_) const;


   /// @brief Return the markup of the object.
   ///
   /// @return the markup text of the object.
   ///
   /// @param text the markup text to use.
   ///
   ::efl::eina::optional< std::string > text_markup_get() const;


   /// @brief Sets the tetxblock's text to the markup text.
   ///
   /// @note assumes text does not include the unicode object replacement char (0xFFFC)
   ///
   /// @return Return no value.
   ///
   /// @param text the markup text to use.
   ///
   void text_markup_set(::efl::eina::optional< std::string > text_) const;


   /// @brief @brief Gets the vertical alignment of a textblock
   ///
   /// @return The alignment set for the object.
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   double valign_get() const;


   /// @brief @brief Sets the vertical alignment of text within the textblock object
   /// as a whole.
   ///
   /// Normally alignment is 0.0 (top of object). Values given should be
   /// between 0.0 and 1.0 (1.0 bottom of object, 0.5 being vertically centered
   /// etc.).
   ///
   /// @since 1.1
   ///
   /// @param align A value between @c 0.0 and @c 1.0.
   ///
   void valign_set(double align_) const;


   /// @brief @brief Gets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @return A null terminated string of delimiters, e.g ",|". If empty, returns
   /// @c NULL.
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   ::efl::eina::optional< std::string > bidi_delimiters_get() const;


   /// @brief @brief Sets the BiDi delimiters used in the textblock.
   ///
   /// BiDi delimiters are use for in-paragraph separation of bidi segments. This
   /// is useful for example in recipients fields of e-mail clients where bidi
   /// oddities can occur when mixing RTL and LTR.
   ///
   /// @since 1.1
   ///
   /// @param delim A null terminated string of delimiters, e.g ",|".
   ///
   void bidi_delimiters_set(::efl::eina::optional< std::string > delim_) const;


   /// @brief @brief Set the "replacement character" to use for the given textblock object.
   ///
   /// @param ch The charset name.
   ///
   void replace_char_set(::efl::eina::optional< std::string > ch_) const;


   /// @brief @brief Gets newline mode. When true, newline character behaves
   /// as a paragraph separator.
   ///
   /// @return @c EINA_TRUE if in legacy mode, @c EINA_FALSE otherwise.
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   bool legacy_newline_get() const;


   /// @brief @brief Sets newline mode. When true, newline character will behave
   /// as a paragraph separator.
   ///
   /// @since 1.1
   ///
   /// @param mode @c EINA_TRUE for legacy mode, @c EINA_FALSE otherwise.
   ///
   void legacy_newline_set(bool mode_) const;


   /// @brief Return the style of an object.
   /// @return the style of the object.
   ///
   /// @param ts the style to set.
   ///
   const Evas_Textblock_Style * style_get() const;


   /// @brief Set the objects style to ts.
   /// @return Returns no value.
   ///
   /// @param ts the style to set.
   ///
   void style_set(const Evas_Textblock_Style * ts_) const;


   /// @brief Returns the first format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_first_get() const;


   /// @brief Get the formatted width and height. This calculates the actual size after restricting
   /// the textblock to the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_native_get
   /// is that the "native" function does not wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while this function gives the size after wrapping
   /// according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   ///
   /// @return Returns no value.
   /// @see evas_object_textblock_size_native_get
   ///
   /// @param w the width of the object.
   /// @param h the height of the object
   ///
   void size_formatted_get(Evas_Coord* w_, Evas_Coord* h_) const;


   /// @brief Returns the last format node.
   ///
   /// @param format 
   ///
   const Evas_Object_Textblock_Node_Format * node_format_last_get() const;


   /// @brief Return the object's main cursor.
   ///
   /// @return The @p obj's main cursor.
   ///
   Evas_Textblock_Cursor * cursor_get() const;


   /// @brief Get the native width and height. This calculates the actual size without taking account
   /// the current size of the object.
   /// The main difference between this and @ref evas_object_textblock_size_formatted_get
   /// is that the "native" function does not take wrapping into account
   /// it just calculates the real width of the object if it was placed on an
   /// infinite canvas, while the "formatted" function gives the size after
   /// wrapping text according to the size restrictions of the object.
   ///
   /// For example for a textblock containing the text: "You shall not pass!"
   /// with no margins or padding and assuming a monospace font and a size of
   /// 7x10 char widths (for simplicity) has a native size of 19x1
   /// and a formatted size of 5x4.
   ///
   /// @return Returns no value.
   ///
   /// @param w the width returned
   /// @param h the height returned
   ///
   void size_native_get(Evas_Coord* w_, Evas_Coord* h_) const;


   /// @brief No description supplied by the EAPI.
   ///
   /// @param l 
   /// @param r 
   /// @param t 
   /// @param b 
   ///
   void style_insets_get(Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_) const;



   static Eo_Class const* _eo_class()
   {
      return(EVAS_TEXTBLOCK_CLASS);
   }

   struct address_of
      : ::eo_cxx::evas::textblock::address_of<address_of>
      , ::eo_cxx::eo::base::address_of<address_of>
      , ::eo_cxx::evas::common_interface::address_of<address_of>
      , ::eo_cxx::evas::object::address_of<address_of>
      , ::efl::eo::detail::concrete_address_of
   {
      explicit address_of(::evas::textblock* p)
         : ::efl::eo::detail::concrete_address_of(p)
      {}
   };
   address_of operator&() { return address_of(this); }

   struct address_const_of
      : ::eo_cxx::evas::textblock::address_const_of<address_const_of>
      , ::eo_cxx::eo::base::address_const_of<address_const_of>
      , ::eo_cxx::evas::common_interface::address_const_of<address_const_of>
      , ::eo_cxx::evas::object::address_const_of<address_const_of>
      , ::efl::eo::detail::concrete_address_const_of
   {
      explicit address_const_of(::evas::textblock const* p)
         : ::efl::eo::detail::concrete_address_const_of(p)
      {}
   };
   address_const_of operator&() const { return address_const_of(this); }

private:
   static Eo* _ctors_call(::efl::eo::parent_type _p)
   {
      Eo* _ret_eo = eo_add_ref(EVAS_TEXTBLOCK_CLASS, _p._eo_raw, );

      return _ret_eo;
   }

      Eo* _concrete_eo_ptr() const { return _eo_ptr(); }
};

static_assert(sizeof(::evas::textblock) == sizeof(Eo*), "");
static_assert(std::is_standard_layout<::evas::textblock>::value, "");

}

inline bool evas::textblock::line_number_geometry_get(int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line_, cx_, cy_, cw_, ch_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline ::efl::eina::optional< std::string > evas::textblock::replace_char_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_replace_char_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::textblock::style_user_pop() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_user_pop());
}


inline Evas_Textblock_Cursor * evas::textblock::cursor_new() const
{
   Evas_Textblock_Cursor * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_new());
   return _tmp_ret;
}


inline ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > evas::textblock::node_format_list_get(::efl::eina::optional< std::string > anchor_) const
{
   const Eina_List * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_list_get(::efl::eolian::to_c(anchor_)));
   return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
}


inline const Evas_Textblock_Style * evas::textblock::style_user_peek() const
{
   const Evas_Textblock_Style * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_user_peek());
   return _tmp_ret;
}


inline void evas::textblock::node_format_remove_pair(Evas_Object_Textblock_Node_Format * n_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_node_format_remove_pair(n_));
}


inline void evas::textblock::clear() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_clear());
}


inline void evas::textblock::style_user_push(Evas_Textblock_Style * ts_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_user_push(ts_));
}


inline ::efl::eina::optional< std::string > evas::textblock::text_markup_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_text_markup_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::textblock::text_markup_set(::efl::eina::optional< std::string > text_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_text_markup_set(::efl::eolian::to_c(text_)));
}


inline double evas::textblock::valign_get() const
{
   double _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_valign_get());
   return _tmp_ret;
}


inline void evas::textblock::valign_set(double align_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_valign_set(align_));
}


inline ::efl::eina::optional< std::string > evas::textblock::bidi_delimiters_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::textblock::bidi_delimiters_set(::efl::eina::optional< std::string > delim_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_bidi_delimiters_set(::efl::eolian::to_c(delim_)));
}


inline void evas::textblock::replace_char_set(::efl::eina::optional< std::string > ch_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_replace_char_set(::efl::eolian::to_c(ch_)));
}


inline bool evas::textblock::legacy_newline_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void evas::textblock::legacy_newline_set(bool mode_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_legacy_newline_set(::efl::eolian::to_c(mode_)));
}


inline const Evas_Textblock_Style * evas::textblock::style_get() const
{
   const Evas_Textblock_Style * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_get());
   return _tmp_ret;
}


inline void evas::textblock::style_set(const Evas_Textblock_Style * ts_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_set(ts_));
}


inline const Evas_Object_Textblock_Node_Format * evas::textblock::node_format_first_get() const
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_first_get());
   return _tmp_ret;
}


inline void evas::textblock::size_formatted_get(Evas_Coord* w_, Evas_Coord* h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_size_formatted_get(w_, h_));
}


inline const Evas_Object_Textblock_Node_Format * evas::textblock::node_format_last_get() const
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_last_get());
   return _tmp_ret;
}


inline Evas_Textblock_Cursor * evas::textblock::cursor_get() const
{
   Evas_Textblock_Cursor * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_get());
   return _tmp_ret;
}


inline void evas::textblock::size_native_get(Evas_Coord* w_, Evas_Coord* h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_size_native_get(w_, h_));
}


inline void evas::textblock::style_insets_get(Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_insets_get(l_, r_, t_, b_));
}


inline bool eo_cxx::evas::textblock::line_number_geometry_get(int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_) const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line_, cx_, cy_, cw_, ch_));
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline ::efl::eina::optional< std::string > eo_cxx::evas::textblock::replace_char_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_replace_char_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::textblock::style_user_pop() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_user_pop());
}


inline Evas_Textblock_Cursor * eo_cxx::evas::textblock::cursor_new() const
{
   Evas_Textblock_Cursor * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_new());
   return _tmp_ret;
}


inline ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > eo_cxx::evas::textblock::node_format_list_get(::efl::eina::optional< std::string > anchor_) const
{
   const Eina_List * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_list_get(::efl::eolian::to_c(anchor_)));
   return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
}


inline const Evas_Textblock_Style * eo_cxx::evas::textblock::style_user_peek() const
{
   const Evas_Textblock_Style * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_user_peek());
   return _tmp_ret;
}


inline void eo_cxx::evas::textblock::node_format_remove_pair(Evas_Object_Textblock_Node_Format * n_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_node_format_remove_pair(n_));
}


inline void eo_cxx::evas::textblock::clear() const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_clear());
}


inline void eo_cxx::evas::textblock::style_user_push(Evas_Textblock_Style * ts_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_user_push(ts_));
}


inline ::efl::eina::optional< std::string > eo_cxx::evas::textblock::text_markup_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_text_markup_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::textblock::text_markup_set(::efl::eina::optional< std::string > text_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_text_markup_set(::efl::eolian::to_c(text_)));
}


inline double eo_cxx::evas::textblock::valign_get() const
{
   double _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_valign_get());
   return _tmp_ret;
}


inline void eo_cxx::evas::textblock::valign_set(double align_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_valign_set(align_));
}


inline ::efl::eina::optional< std::string > eo_cxx::evas::textblock::bidi_delimiters_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
   return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::textblock::bidi_delimiters_set(::efl::eina::optional< std::string > delim_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_bidi_delimiters_set(::efl::eolian::to_c(delim_)));
}


inline void eo_cxx::evas::textblock::replace_char_set(::efl::eina::optional< std::string > ch_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_replace_char_set(::efl::eolian::to_c(ch_)));
}


inline bool eo_cxx::evas::textblock::legacy_newline_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}


inline void eo_cxx::evas::textblock::legacy_newline_set(bool mode_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_legacy_newline_set(::efl::eolian::to_c(mode_)));
}


inline const Evas_Textblock_Style * eo_cxx::evas::textblock::style_get() const
{
   const Evas_Textblock_Style * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_style_get());
   return _tmp_ret;
}


inline void eo_cxx::evas::textblock::style_set(const Evas_Textblock_Style * ts_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_set(ts_));
}


inline const Evas_Object_Textblock_Node_Format * eo_cxx::evas::textblock::node_format_first_get() const
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_first_get());
   return _tmp_ret;
}


inline void eo_cxx::evas::textblock::size_formatted_get(Evas_Coord* w_, Evas_Coord* h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_size_formatted_get(w_, h_));
}


inline const Evas_Object_Textblock_Node_Format * eo_cxx::evas::textblock::node_format_last_get() const
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_node_format_last_get());
   return _tmp_ret;
}


inline Evas_Textblock_Cursor * eo_cxx::evas::textblock::cursor_get() const
{
   Evas_Textblock_Cursor * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::evas_obj_textblock_cursor_get());
   return _tmp_ret;
}


inline void eo_cxx::evas::textblock::size_native_get(Evas_Coord* w_, Evas_Coord* h_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_size_native_get(w_, h_));
}


inline void eo_cxx::evas::textblock::style_insets_get(Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_) const
{
   eo_do(_concrete_eo_ptr(), ::evas_obj_textblock_style_insets_get(l_, r_, t_, b_));
}


inline ::eo_cxx::evas::textblock::operator ::evas::textblock() const
{
   return *static_cast<::evas::textblock const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::evas::textblock::operator ::evas::textblock&()
{
   return *static_cast<::evas::textblock*>(static_cast<void*>(this));
}

inline ::eo_cxx::evas::textblock::operator ::evas::textblock const&() const
{
   return *static_cast<::evas::textblock const*>(static_cast<void const*>(this));
}

template <typename T>
bool evas_textblock_line_number_geometry_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->line_number_geometry_get(line_, cx_, cy_, cw_, ch_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
::efl::eina::optional< std::string > evas_textblock_replace_char_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   ::efl::eina::optional< std::string > _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->replace_char_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_style_user_pop_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->style_user_pop();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
Evas_Textblock_Cursor * evas_textblock_cursor_new_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_Textblock_Cursor * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->cursor_new();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > evas_textblock_node_format_list_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * anchor_)
{
   ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->node_format_list_get(::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(anchor_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
const Evas_Textblock_Style * evas_textblock_style_user_peek_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   const Evas_Textblock_Style * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->style_user_peek();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_node_format_remove_pair_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Object_Textblock_Node_Format * n_)
{
   try
      {
         static_cast<T*>(self->this_)->node_format_remove_pair(n_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_textblock_clear_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         static_cast<T*>(self->this_)->clear();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_textblock_style_user_push_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Textblock_Style * ts_)
{
   try
      {
         static_cast<T*>(self->this_)->style_user_push(ts_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
::efl::eina::optional< std::string > evas_textblock_text_markup_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   ::efl::eina::optional< std::string > _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->text_markup_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_text_markup_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * text_)
{
   try
      {
         static_cast<T*>(self->this_)->text_markup_set(::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(text_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
double evas_textblock_valign_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   double _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->valign_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_valign_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, double align_)
{
   try
      {
         static_cast<T*>(self->this_)->valign_set(align_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
::efl::eina::optional< std::string > evas_textblock_bidi_delimiters_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   ::efl::eina::optional< std::string > _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->bidi_delimiters_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_bidi_delimiters_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * delim_)
{
   try
      {
         static_cast<T*>(self->this_)->bidi_delimiters_set(::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(delim_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_textblock_replace_char_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * ch_)
{
   try
      {
         static_cast<T*>(self->this_)->replace_char_set(::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(ch_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool evas_textblock_legacy_newline_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   bool _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->legacy_newline_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_legacy_newline_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_Bool mode_)
{
   try
      {
         static_cast<T*>(self->this_)->legacy_newline_set(::efl::eolian::to_cxx<bool>(mode_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
const Evas_Textblock_Style * evas_textblock_style_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   const Evas_Textblock_Style * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->style_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_style_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const Evas_Textblock_Style * ts_)
{
   try
      {
         static_cast<T*>(self->this_)->style_set(ts_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
const Evas_Object_Textblock_Node_Format * evas_textblock_node_format_first_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->node_format_first_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_size_formatted_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w_, Evas_Coord* h_)
{
   try
      {
         static_cast<T*>(self->this_)->size_formatted_get(w_, h_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
const Evas_Object_Textblock_Node_Format * evas_textblock_node_format_last_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   const Evas_Object_Textblock_Node_Format * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->node_format_last_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
Evas_Textblock_Cursor * evas_textblock_cursor_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   Evas_Textblock_Cursor * _tmp_ret{};
   try
      {
         _tmp_ret = static_cast<T*>(self->this_)->cursor_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
   return _tmp_ret;
}

template <typename T>
void evas_textblock_size_native_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* w_, Evas_Coord* h_)
{
   try
      {
         static_cast<T*>(self->this_)->size_native_get(w_, h_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
void evas_textblock_style_insets_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_)
{
   try
      {
         static_cast<T*>(self->this_)->style_insets_get(l_, r_, t_, b_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::evas::textblock >
{
   template <typename T>
   struct type
         : virtual operations< ::evas::object >::template type<T>
   {
      virtual bool line_number_geometry_get(int line_, Evas_Coord* cx_, Evas_Coord* cy_, Evas_Coord* cw_, Evas_Coord* ch_)
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_line_number_geometry_get(line_, cx_, cy_, cw_, ch_));
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual ::efl::eina::optional< std::string > replace_char_get()
      {
         const char * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_replace_char_get());
            return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void style_user_pop()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_style_user_pop());
      }

      virtual Evas_Textblock_Cursor * cursor_new()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_cursor_new());
            return _tmp_ret;
      }

      virtual ::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > > node_format_list_get(::efl::eina::optional< std::string > anchor_)
      {
         const Eina_List * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_node_format_list_get(::efl::eolian::to_c(anchor_)));
            return ::efl::eolian::to_cxx<::efl::eina::optional< ::efl::eina::crange_list< ::evas::object > >>(_tmp_ret, std::tuple<std::false_type, std::false_type>());
      }

      virtual const Evas_Textblock_Style * style_user_peek()
      {
         const Evas_Textblock_Style * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_style_user_peek());
            return _tmp_ret;
      }

      virtual void node_format_remove_pair(Evas_Object_Textblock_Node_Format * n_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_node_format_remove_pair(n_));
      }

      virtual void clear()
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_clear());
      }

      virtual void style_user_push(Evas_Textblock_Style * ts_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_style_user_push(ts_));
      }

      virtual ::efl::eina::optional< std::string > text_markup_get()
      {
         const char * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_text_markup_get());
            return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void text_markup_set(::efl::eina::optional< std::string > text_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_text_markup_set(::efl::eolian::to_c(text_)));
      }

      virtual double valign_get()
      {
         double _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_valign_get());
            return _tmp_ret;
      }

      virtual void valign_set(double align_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_valign_set(align_));
      }

      virtual ::efl::eina::optional< std::string > bidi_delimiters_get()
      {
         const char * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_bidi_delimiters_get());
            return ::efl::eolian::to_cxx<::efl::eina::optional< std::string >>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void bidi_delimiters_set(::efl::eina::optional< std::string > delim_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_bidi_delimiters_set(::efl::eolian::to_c(delim_)));
      }

      virtual void replace_char_set(::efl::eina::optional< std::string > ch_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_replace_char_set(::efl::eolian::to_c(ch_)));
      }

      virtual bool legacy_newline_get()
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_legacy_newline_get());
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void legacy_newline_set(bool mode_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_legacy_newline_set(::efl::eolian::to_c(mode_)));
      }

      virtual const Evas_Textblock_Style * style_get()
      {
         const Evas_Textblock_Style * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_style_get());
            return _tmp_ret;
      }

      virtual void style_set(const Evas_Textblock_Style * ts_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_style_set(ts_));
      }

      virtual const Evas_Object_Textblock_Node_Format * node_format_first_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_node_format_first_get());
            return _tmp_ret;
      }

      virtual void size_formatted_get(Evas_Coord* w_, Evas_Coord* h_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_size_formatted_get(w_, h_));
      }

      virtual const Evas_Object_Textblock_Node_Format * node_format_last_get()
      {
         const Evas_Object_Textblock_Node_Format * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_node_format_last_get());
            return _tmp_ret;
      }

      virtual Evas_Textblock_Cursor * cursor_get()
      {
         Evas_Textblock_Cursor * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::evas_obj_textblock_cursor_get());
            return _tmp_ret;
      }

      virtual void size_native_get(Evas_Coord* w_, Evas_Coord* h_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_size_native_get(w_, h_));
      }

      virtual void style_insets_get(Evas_Coord* l_, Evas_Coord* r_, Evas_Coord* t_, Evas_Coord* b_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::evas_obj_textblock_style_insets_get(l_, r_, t_, b_));
      }

   };
};


template<>
struct operation_description_class_size< ::evas::textblock >
{
   static const int value = 26 + operation_description_class_size<::evas::object >::value;
};

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::evas::textblock>
                                 , Eo_Op_Description* ops)
{
   (void)ops;
   ops[0].func = reinterpret_cast<void*>(& ::evas_textblock_line_number_geometry_get_wrapper<T>);
   ops[0].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_line_number_geometry_get);
   ops[0].op = EO_OP_OVERRIDE;
   ops[0].op_type = EO_OP_TYPE_REGULAR;
   ops[0].doc = NULL;

   ops[1].func = reinterpret_cast<void*>(& ::evas_textblock_replace_char_get_wrapper<T>);
   ops[1].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_replace_char_get);
   ops[1].op = EO_OP_OVERRIDE;
   ops[1].op_type = EO_OP_TYPE_REGULAR;
   ops[1].doc = NULL;

   ops[2].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_pop_wrapper<T>);
   ops[2].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_pop);
   ops[2].op = EO_OP_OVERRIDE;
   ops[2].op_type = EO_OP_TYPE_REGULAR;
   ops[2].doc = NULL;

   ops[3].func = reinterpret_cast<void*>(& ::evas_textblock_cursor_new_wrapper<T>);
   ops[3].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_cursor_new);
   ops[3].op = EO_OP_OVERRIDE;
   ops[3].op_type = EO_OP_TYPE_REGULAR;
   ops[3].doc = NULL;

   ops[4].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_list_get_wrapper<T>);
   ops[4].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_list_get);
   ops[4].op = EO_OP_OVERRIDE;
   ops[4].op_type = EO_OP_TYPE_REGULAR;
   ops[4].doc = NULL;

   ops[5].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_peek_wrapper<T>);
   ops[5].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_peek);
   ops[5].op = EO_OP_OVERRIDE;
   ops[5].op_type = EO_OP_TYPE_REGULAR;
   ops[5].doc = NULL;

   ops[6].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_remove_pair_wrapper<T>);
   ops[6].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_remove_pair);
   ops[6].op = EO_OP_OVERRIDE;
   ops[6].op_type = EO_OP_TYPE_REGULAR;
   ops[6].doc = NULL;

   ops[7].func = reinterpret_cast<void*>(& ::evas_textblock_clear_wrapper<T>);
   ops[7].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_clear);
   ops[7].op = EO_OP_OVERRIDE;
   ops[7].op_type = EO_OP_TYPE_REGULAR;
   ops[7].doc = NULL;

   ops[8].func = reinterpret_cast<void*>(& ::evas_textblock_style_user_push_wrapper<T>);
   ops[8].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_user_push);
   ops[8].op = EO_OP_OVERRIDE;
   ops[8].op_type = EO_OP_TYPE_REGULAR;
   ops[8].doc = NULL;

   ops[9].func = reinterpret_cast<void*>(& ::evas_textblock_text_markup_get_wrapper<T>);
   ops[9].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_text_markup_get);
   ops[9].op = EO_OP_OVERRIDE;
   ops[9].op_type = EO_OP_TYPE_REGULAR;
   ops[9].doc = NULL;

   ops[10].func = reinterpret_cast<void*>(& ::evas_textblock_text_markup_set_wrapper<T>);
   ops[10].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_text_markup_set);
   ops[10].op = EO_OP_OVERRIDE;
   ops[10].op_type = EO_OP_TYPE_REGULAR;
   ops[10].doc = NULL;

   ops[11].func = reinterpret_cast<void*>(& ::evas_textblock_valign_get_wrapper<T>);
   ops[11].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_valign_get);
   ops[11].op = EO_OP_OVERRIDE;
   ops[11].op_type = EO_OP_TYPE_REGULAR;
   ops[11].doc = NULL;

   ops[12].func = reinterpret_cast<void*>(& ::evas_textblock_valign_set_wrapper<T>);
   ops[12].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_valign_set);
   ops[12].op = EO_OP_OVERRIDE;
   ops[12].op_type = EO_OP_TYPE_REGULAR;
   ops[12].doc = NULL;

   ops[13].func = reinterpret_cast<void*>(& ::evas_textblock_bidi_delimiters_get_wrapper<T>);
   ops[13].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_bidi_delimiters_get);
   ops[13].op = EO_OP_OVERRIDE;
   ops[13].op_type = EO_OP_TYPE_REGULAR;
   ops[13].doc = NULL;

   ops[14].func = reinterpret_cast<void*>(& ::evas_textblock_bidi_delimiters_set_wrapper<T>);
   ops[14].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_bidi_delimiters_set);
   ops[14].op = EO_OP_OVERRIDE;
   ops[14].op_type = EO_OP_TYPE_REGULAR;
   ops[14].doc = NULL;

   ops[15].func = reinterpret_cast<void*>(& ::evas_textblock_replace_char_set_wrapper<T>);
   ops[15].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_replace_char_set);
   ops[15].op = EO_OP_OVERRIDE;
   ops[15].op_type = EO_OP_TYPE_REGULAR;
   ops[15].doc = NULL;

   ops[16].func = reinterpret_cast<void*>(& ::evas_textblock_legacy_newline_get_wrapper<T>);
   ops[16].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_legacy_newline_get);
   ops[16].op = EO_OP_OVERRIDE;
   ops[16].op_type = EO_OP_TYPE_REGULAR;
   ops[16].doc = NULL;

   ops[17].func = reinterpret_cast<void*>(& ::evas_textblock_legacy_newline_set_wrapper<T>);
   ops[17].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_legacy_newline_set);
   ops[17].op = EO_OP_OVERRIDE;
   ops[17].op_type = EO_OP_TYPE_REGULAR;
   ops[17].doc = NULL;

   ops[18].func = reinterpret_cast<void*>(& ::evas_textblock_style_get_wrapper<T>);
   ops[18].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_get);
   ops[18].op = EO_OP_OVERRIDE;
   ops[18].op_type = EO_OP_TYPE_REGULAR;
   ops[18].doc = NULL;

   ops[19].func = reinterpret_cast<void*>(& ::evas_textblock_style_set_wrapper<T>);
   ops[19].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_set);
   ops[19].op = EO_OP_OVERRIDE;
   ops[19].op_type = EO_OP_TYPE_REGULAR;
   ops[19].doc = NULL;

   ops[20].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_first_get_wrapper<T>);
   ops[20].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_first_get);
   ops[20].op = EO_OP_OVERRIDE;
   ops[20].op_type = EO_OP_TYPE_REGULAR;
   ops[20].doc = NULL;

   ops[21].func = reinterpret_cast<void*>(& ::evas_textblock_size_formatted_get_wrapper<T>);
   ops[21].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_size_formatted_get);
   ops[21].op = EO_OP_OVERRIDE;
   ops[21].op_type = EO_OP_TYPE_REGULAR;
   ops[21].doc = NULL;

   ops[22].func = reinterpret_cast<void*>(& ::evas_textblock_node_format_last_get_wrapper<T>);
   ops[22].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_node_format_last_get);
   ops[22].op = EO_OP_OVERRIDE;
   ops[22].op_type = EO_OP_TYPE_REGULAR;
   ops[22].doc = NULL;

   ops[23].func = reinterpret_cast<void*>(& ::evas_textblock_cursor_get_wrapper<T>);
   ops[23].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_cursor_get);
   ops[23].op = EO_OP_OVERRIDE;
   ops[23].op_type = EO_OP_TYPE_REGULAR;
   ops[23].doc = NULL;

   ops[24].func = reinterpret_cast<void*>(& ::evas_textblock_size_native_get_wrapper<T>);
   ops[24].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_size_native_get);
   ops[24].op = EO_OP_OVERRIDE;
   ops[24].op_type = EO_OP_TYPE_REGULAR;
   ops[24].doc = NULL;

   ops[25].func = reinterpret_cast<void*>(& ::evas_textblock_style_insets_get_wrapper<T>);
   ops[25].api_func = reinterpret_cast<void*>(& ::evas_obj_textblock_style_insets_get);
   ops[25].op = EO_OP_OVERRIDE;
   ops[25].op_type = EO_OP_TYPE_REGULAR;
   ops[25].doc = NULL;

   initialize_operation_description<T>(::efl::eo::detail::tag<::evas::object>(), &ops[26]);
   return 0;
}
inline void
call_constructor(::efl::eo::detail::tag< ::evas::textblock >
               , Eo* eo, Eo_Class const* cls EINA_UNUSED,
               ::efl::eo::detail::args_class<::evas::textblock, ::std::tuple<::efl::eo::parent_type> > const& args)
{
   eo_do(eo, ::eo_parent_set(args.get<0>()._eo_raw));
}

inline Eo_Class const* get_eo_class(tag<::evas::textblock>)
{
   return (EVAS_TEXTBLOCK_CLASS);
}

} } }
#endif // EFL_GENERATED_EVAS_TEXTBLOCK_HH

